from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.table_schema_column_count_changed_check_spec import (
        TableSchemaColumnCountChangedCheckSpec,
    )
    from ..models.table_schema_column_count_check_spec import (
        TableSchemaColumnCountCheckSpec,
    )
    from ..models.table_schema_column_list_changed_check_spec import (
        TableSchemaColumnListChangedCheckSpec,
    )
    from ..models.table_schema_column_list_or_order_changed_check_spec import (
        TableSchemaColumnListOrOrderChangedCheckSpec,
    )
    from ..models.table_schema_column_types_changed_check_spec import (
        TableSchemaColumnTypesChangedCheckSpec,
    )


T = TypeVar("T", bound="TableSchemaMonthlyRecurringChecksSpec")


@attr.s(auto_attribs=True)
class TableSchemaMonthlyRecurringChecksSpec:
    """
    Attributes:
        monthly_column_count (Union[Unset, TableSchemaColumnCountCheckSpec]):
        monthly_column_count_changed (Union[Unset, TableSchemaColumnCountChangedCheckSpec]):
        monthly_column_list_changed (Union[Unset, TableSchemaColumnListChangedCheckSpec]):
        monthly_column_list_or_order_changed (Union[Unset, TableSchemaColumnListOrOrderChangedCheckSpec]):
        monthly_column_types_changed (Union[Unset, TableSchemaColumnTypesChangedCheckSpec]):
    """

    monthly_column_count: Union[Unset, "TableSchemaColumnCountCheckSpec"] = UNSET
    monthly_column_count_changed: Union[
        Unset, "TableSchemaColumnCountChangedCheckSpec"
    ] = UNSET
    monthly_column_list_changed: Union[
        Unset, "TableSchemaColumnListChangedCheckSpec"
    ] = UNSET
    monthly_column_list_or_order_changed: Union[
        Unset, "TableSchemaColumnListOrOrderChangedCheckSpec"
    ] = UNSET
    monthly_column_types_changed: Union[
        Unset, "TableSchemaColumnTypesChangedCheckSpec"
    ] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        monthly_column_count: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_column_count, Unset):
            monthly_column_count = self.monthly_column_count.to_dict()

        monthly_column_count_changed: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_column_count_changed, Unset):
            monthly_column_count_changed = self.monthly_column_count_changed.to_dict()

        monthly_column_list_changed: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_column_list_changed, Unset):
            monthly_column_list_changed = self.monthly_column_list_changed.to_dict()

        monthly_column_list_or_order_changed: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_column_list_or_order_changed, Unset):
            monthly_column_list_or_order_changed = (
                self.monthly_column_list_or_order_changed.to_dict()
            )

        monthly_column_types_changed: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_column_types_changed, Unset):
            monthly_column_types_changed = self.monthly_column_types_changed.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if monthly_column_count is not UNSET:
            field_dict["monthly_column_count"] = monthly_column_count
        if monthly_column_count_changed is not UNSET:
            field_dict["monthly_column_count_changed"] = monthly_column_count_changed
        if monthly_column_list_changed is not UNSET:
            field_dict["monthly_column_list_changed"] = monthly_column_list_changed
        if monthly_column_list_or_order_changed is not UNSET:
            field_dict[
                "monthly_column_list_or_order_changed"
            ] = monthly_column_list_or_order_changed
        if monthly_column_types_changed is not UNSET:
            field_dict["monthly_column_types_changed"] = monthly_column_types_changed

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.table_schema_column_count_changed_check_spec import (
            TableSchemaColumnCountChangedCheckSpec,
        )
        from ..models.table_schema_column_count_check_spec import (
            TableSchemaColumnCountCheckSpec,
        )
        from ..models.table_schema_column_list_changed_check_spec import (
            TableSchemaColumnListChangedCheckSpec,
        )
        from ..models.table_schema_column_list_or_order_changed_check_spec import (
            TableSchemaColumnListOrOrderChangedCheckSpec,
        )
        from ..models.table_schema_column_types_changed_check_spec import (
            TableSchemaColumnTypesChangedCheckSpec,
        )

        d = src_dict.copy()
        _monthly_column_count = d.pop("monthly_column_count", UNSET)
        monthly_column_count: Union[Unset, TableSchemaColumnCountCheckSpec]
        if isinstance(_monthly_column_count, Unset):
            monthly_column_count = UNSET
        else:
            monthly_column_count = TableSchemaColumnCountCheckSpec.from_dict(
                _monthly_column_count
            )

        _monthly_column_count_changed = d.pop("monthly_column_count_changed", UNSET)
        monthly_column_count_changed: Union[
            Unset, TableSchemaColumnCountChangedCheckSpec
        ]
        if isinstance(_monthly_column_count_changed, Unset):
            monthly_column_count_changed = UNSET
        else:
            monthly_column_count_changed = (
                TableSchemaColumnCountChangedCheckSpec.from_dict(
                    _monthly_column_count_changed
                )
            )

        _monthly_column_list_changed = d.pop("monthly_column_list_changed", UNSET)
        monthly_column_list_changed: Union[Unset, TableSchemaColumnListChangedCheckSpec]
        if isinstance(_monthly_column_list_changed, Unset):
            monthly_column_list_changed = UNSET
        else:
            monthly_column_list_changed = (
                TableSchemaColumnListChangedCheckSpec.from_dict(
                    _monthly_column_list_changed
                )
            )

        _monthly_column_list_or_order_changed = d.pop(
            "monthly_column_list_or_order_changed", UNSET
        )
        monthly_column_list_or_order_changed: Union[
            Unset, TableSchemaColumnListOrOrderChangedCheckSpec
        ]
        if isinstance(_monthly_column_list_or_order_changed, Unset):
            monthly_column_list_or_order_changed = UNSET
        else:
            monthly_column_list_or_order_changed = (
                TableSchemaColumnListOrOrderChangedCheckSpec.from_dict(
                    _monthly_column_list_or_order_changed
                )
            )

        _monthly_column_types_changed = d.pop("monthly_column_types_changed", UNSET)
        monthly_column_types_changed: Union[
            Unset, TableSchemaColumnTypesChangedCheckSpec
        ]
        if isinstance(_monthly_column_types_changed, Unset):
            monthly_column_types_changed = UNSET
        else:
            monthly_column_types_changed = (
                TableSchemaColumnTypesChangedCheckSpec.from_dict(
                    _monthly_column_types_changed
                )
            )

        table_schema_monthly_recurring_checks_spec = cls(
            monthly_column_count=monthly_column_count,
            monthly_column_count_changed=monthly_column_count_changed,
            monthly_column_list_changed=monthly_column_list_changed,
            monthly_column_list_or_order_changed=monthly_column_list_or_order_changed,
            monthly_column_types_changed=monthly_column_types_changed,
        )

        table_schema_monthly_recurring_checks_spec.additional_properties = d
        return table_schema_monthly_recurring_checks_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.column_date_values_in_future_percent_check_spec import (
        ColumnDateValuesInFuturePercentCheckSpec,
    )
    from ..models.column_datetime_value_in_range_date_percent_check_spec import (
        ColumnDatetimeValueInRangeDatePercentCheckSpec,
    )


T = TypeVar("T", bound="ColumnDatetimeProfilingChecksSpec")


@attr.s(auto_attribs=True)
class ColumnDatetimeProfilingChecksSpec:
    """
    Attributes:
        profile_date_values_in_future_percent (Union[Unset, ColumnDateValuesInFuturePercentCheckSpec]):
        profile_datetime_value_in_range_date_percent (Union[Unset, ColumnDatetimeValueInRangeDatePercentCheckSpec]):
    """

    profile_date_values_in_future_percent: Union[
        Unset, "ColumnDateValuesInFuturePercentCheckSpec"
    ] = UNSET
    profile_datetime_value_in_range_date_percent: Union[
        Unset, "ColumnDatetimeValueInRangeDatePercentCheckSpec"
    ] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        profile_date_values_in_future_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_date_values_in_future_percent, Unset):
            profile_date_values_in_future_percent = (
                self.profile_date_values_in_future_percent.to_dict()
            )

        profile_datetime_value_in_range_date_percent: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(self.profile_datetime_value_in_range_date_percent, Unset):
            profile_datetime_value_in_range_date_percent = (
                self.profile_datetime_value_in_range_date_percent.to_dict()
            )

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if profile_date_values_in_future_percent is not UNSET:
            field_dict[
                "profile_date_values_in_future_percent"
            ] = profile_date_values_in_future_percent
        if profile_datetime_value_in_range_date_percent is not UNSET:
            field_dict[
                "profile_datetime_value_in_range_date_percent"
            ] = profile_datetime_value_in_range_date_percent

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.column_date_values_in_future_percent_check_spec import (
            ColumnDateValuesInFuturePercentCheckSpec,
        )
        from ..models.column_datetime_value_in_range_date_percent_check_spec import (
            ColumnDatetimeValueInRangeDatePercentCheckSpec,
        )

        d = src_dict.copy()
        _profile_date_values_in_future_percent = d.pop(
            "profile_date_values_in_future_percent", UNSET
        )
        profile_date_values_in_future_percent: Union[
            Unset, ColumnDateValuesInFuturePercentCheckSpec
        ]
        if isinstance(_profile_date_values_in_future_percent, Unset):
            profile_date_values_in_future_percent = UNSET
        else:
            profile_date_values_in_future_percent = (
                ColumnDateValuesInFuturePercentCheckSpec.from_dict(
                    _profile_date_values_in_future_percent
                )
            )

        _profile_datetime_value_in_range_date_percent = d.pop(
            "profile_datetime_value_in_range_date_percent", UNSET
        )
        profile_datetime_value_in_range_date_percent: Union[
            Unset, ColumnDatetimeValueInRangeDatePercentCheckSpec
        ]
        if isinstance(_profile_datetime_value_in_range_date_percent, Unset):
            profile_datetime_value_in_range_date_percent = UNSET
        else:
            profile_datetime_value_in_range_date_percent = (
                ColumnDatetimeValueInRangeDatePercentCheckSpec.from_dict(
                    _profile_datetime_value_in_range_date_percent
                )
            )

        column_datetime_profiling_checks_spec = cls(
            profile_date_values_in_future_percent=profile_date_values_in_future_percent,
            profile_datetime_value_in_range_date_percent=profile_datetime_value_in_range_date_percent,
        )

        column_datetime_profiling_checks_spec.additional_properties = d
        return column_datetime_profiling_checks_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="AnomalyDifferencingPercentileMovingAverageRule05ParametersSpec")


@attr.s(auto_attribs=True)
class AnomalyDifferencingPercentileMovingAverageRule05ParametersSpec:
    """
    Attributes:
        anomaly_percent (Union[Unset, float]): Probability that the current sensor readout will achieve values within
            the mean according to the distribution of the previous values gathered within the time window. In other words,
            the inter-quantile range around the mean of the estimated normal distribution. Set the time window at the
            threshold level for all severity levels (warning, error, fatal) at once. The default is a time window of 90
            periods (days, etc.), but at least 30 readouts must exist to run the calculation. You can change the default
            value by modifying prediction_time_window parameterin Definitions section.
    """

    anomaly_percent: Union[Unset, float] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        anomaly_percent = self.anomaly_percent

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if anomaly_percent is not UNSET:
            field_dict["anomaly_percent"] = anomaly_percent

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        anomaly_percent = d.pop("anomaly_percent", UNSET)

        anomaly_differencing_percentile_moving_average_rule_05_parameters_spec = cls(
            anomaly_percent=anomaly_percent,
        )

        anomaly_differencing_percentile_moving_average_rule_05_parameters_spec.additional_properties = (
            d
        )
        return anomaly_differencing_percentile_moving_average_rule_05_parameters_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="TableComparisonGroupingColumnPairModel")


@attr.s(auto_attribs=True)
class TableComparisonGroupingColumnPairModel:
    """Model that identifies a pair of column names used for grouping the data on both the compared table and the reference
    table. The groups are then matched (joined) by DQO to compare aggregated results.

        Attributes:
            compared_table_column_name (Union[Unset, str]): The name of the column on the compared table (the parent table)
                that is used in the GROUP BY clause to group rows before compared aggregates (row counts, sums, etc.) are
                calculated. This column is also used to join (match) results to the reference table.
            reference_table_column_name (Union[Unset, str]): The name of the column on the reference table (the source of
                truth) that is used in the GROUP BY clause to group rows before compared aggregates (row counts, sums, etc.) are
                calculated. This column is also used to join (match) results to the compared table.
    """

    compared_table_column_name: Union[Unset, str] = UNSET
    reference_table_column_name: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        compared_table_column_name = self.compared_table_column_name
        reference_table_column_name = self.reference_table_column_name

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if compared_table_column_name is not UNSET:
            field_dict["compared_table_column_name"] = compared_table_column_name
        if reference_table_column_name is not UNSET:
            field_dict["reference_table_column_name"] = reference_table_column_name

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        compared_table_column_name = d.pop("compared_table_column_name", UNSET)

        reference_table_column_name = d.pop("reference_table_column_name", UNSET)

        table_comparison_grouping_column_pair_model = cls(
            compared_table_column_name=compared_table_column_name,
            reference_table_column_name=reference_table_column_name,
        )

        table_comparison_grouping_column_pair_model.additional_properties = d
        return table_comparison_grouping_column_pair_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.provider_sensor_model import ProviderSensorModel
    from ..models.sensor_definition_spec import SensorDefinitionSpec


T = TypeVar("T", bound="SensorModel")


@attr.s(auto_attribs=True)
class SensorModel:
    """Sensor model.

    Attributes:
        full_sensor_name (Union[Unset, str]): Full sensor name.
        sensor_definition_spec (Union[Unset, SensorDefinitionSpec]):
        provider_sensor_list (Union[Unset, List['ProviderSensorModel']]): Provider sensors list with provider specific
            sensor definitions.
        custom (Union[Unset, bool]): Whether the sensor is a User Home sensor
        built_in (Union[Unset, bool]): This is a DQO built-in sensor, whose parameters cannot be changed.
    """

    full_sensor_name: Union[Unset, str] = UNSET
    sensor_definition_spec: Union[Unset, "SensorDefinitionSpec"] = UNSET
    provider_sensor_list: Union[Unset, List["ProviderSensorModel"]] = UNSET
    custom: Union[Unset, bool] = UNSET
    built_in: Union[Unset, bool] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        full_sensor_name = self.full_sensor_name
        sensor_definition_spec: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.sensor_definition_spec, Unset):
            sensor_definition_spec = self.sensor_definition_spec.to_dict()

        provider_sensor_list: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.provider_sensor_list, Unset):
            provider_sensor_list = []
            for provider_sensor_list_item_data in self.provider_sensor_list:
                provider_sensor_list_item = provider_sensor_list_item_data.to_dict()

                provider_sensor_list.append(provider_sensor_list_item)

        custom = self.custom
        built_in = self.built_in

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if full_sensor_name is not UNSET:
            field_dict["full_sensor_name"] = full_sensor_name
        if sensor_definition_spec is not UNSET:
            field_dict["sensor_definition_spec"] = sensor_definition_spec
        if provider_sensor_list is not UNSET:
            field_dict["provider_sensor_list"] = provider_sensor_list
        if custom is not UNSET:
            field_dict["custom"] = custom
        if built_in is not UNSET:
            field_dict["built_in"] = built_in

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.provider_sensor_model import ProviderSensorModel
        from ..models.sensor_definition_spec import SensorDefinitionSpec

        d = src_dict.copy()
        full_sensor_name = d.pop("full_sensor_name", UNSET)

        _sensor_definition_spec = d.pop("sensor_definition_spec", UNSET)
        sensor_definition_spec: Union[Unset, SensorDefinitionSpec]
        if isinstance(_sensor_definition_spec, Unset):
            sensor_definition_spec = UNSET
        else:
            sensor_definition_spec = SensorDefinitionSpec.from_dict(
                _sensor_definition_spec
            )

        provider_sensor_list = []
        _provider_sensor_list = d.pop("provider_sensor_list", UNSET)
        for provider_sensor_list_item_data in _provider_sensor_list or []:
            provider_sensor_list_item = ProviderSensorModel.from_dict(
                provider_sensor_list_item_data
            )

            provider_sensor_list.append(provider_sensor_list_item)

        custom = d.pop("custom", UNSET)

        built_in = d.pop("built_in", UNSET)

        sensor_model = cls(
            full_sensor_name=full_sensor_name,
            sensor_definition_spec=sensor_definition_spec,
            provider_sensor_list=provider_sensor_list,
            custom=custom,
            built_in=built_in,
        )

        sensor_model.additional_properties = d
        return sensor_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from http import HTTPStatus
from typing import Any, Dict, Optional, Union

import httpx

from ... import errors
from ...client import Client
from ...models.get_table_data_quality_status_check_time_scale import (
    GetTableDataQualityStatusCheckTimeScale,
)
from ...models.get_table_data_quality_status_check_type import (
    GetTableDataQualityStatusCheckType,
)
from ...models.table_data_quality_status_model import TableDataQualityStatusModel
from ...types import UNSET, Response, Unset


def _get_kwargs(
    connection_name: str,
    schema_name: str,
    table_name: str,
    *,
    client: Client,
    months: Union[Unset, None, int] = UNSET,
    check_type: Union[Unset, None, GetTableDataQualityStatusCheckType] = UNSET,
    check_time_scale: Union[
        Unset, None, GetTableDataQualityStatusCheckTimeScale
    ] = UNSET,
) -> Dict[str, Any]:
    url = "{}api/connections/{connectionName}/schemas/{schemaName}/tables/{tableName}/status".format(
        client.base_url,
        connectionName=connection_name,
        schemaName=schema_name,
        tableName=table_name,
    )

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {}
    params["months"] = months

    json_check_type: Union[Unset, None, str] = UNSET
    if not isinstance(check_type, Unset):
        json_check_type = check_type.value if check_type else None

    params["checkType"] = json_check_type

    json_check_time_scale: Union[Unset, None, str] = UNSET
    if not isinstance(check_time_scale, Unset):
        json_check_time_scale = check_time_scale.value if check_time_scale else None

    params["checkTimeScale"] = json_check_time_scale

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "method": "get",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "follow_redirects": client.follow_redirects,
        "params": params,
    }


def _parse_response(
    *, client: Client, response: httpx.Response
) -> Optional[TableDataQualityStatusModel]:
    if response.status_code == HTTPStatus.OK:
        response_200 = TableDataQualityStatusModel.from_dict(response.json())

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Client, response: httpx.Response
) -> Response[TableDataQualityStatusModel]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    connection_name: str,
    schema_name: str,
    table_name: str,
    *,
    client: Client,
    months: Union[Unset, None, int] = UNSET,
    check_type: Union[Unset, None, GetTableDataQualityStatusCheckType] = UNSET,
    check_time_scale: Union[
        Unset, None, GetTableDataQualityStatusCheckTimeScale
    ] = UNSET,
) -> Response[TableDataQualityStatusModel]:
    """getTableDataQualityStatus

     Read the most recent results of executed data quality checks on the table and return the current
    table's data quality status - the number of failed data quality checks if the table has active data
    quality issues. Also returns the names of data quality checks that did not pass most recently. This
    operation verifies only the status of the most recently executed data quality checks. Previous data
    quality issues are not counted.

    Args:
        connection_name (str):
        schema_name (str):
        table_name (str):
        months (Union[Unset, None, int]):
        check_type (Union[Unset, None, GetTableDataQualityStatusCheckType]):
        check_time_scale (Union[Unset, None, GetTableDataQualityStatusCheckTimeScale]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[TableDataQualityStatusModel]
    """

    kwargs = _get_kwargs(
        connection_name=connection_name,
        schema_name=schema_name,
        table_name=table_name,
        client=client,
        months=months,
        check_type=check_type,
        check_time_scale=check_time_scale,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    connection_name: str,
    schema_name: str,
    table_name: str,
    *,
    client: Client,
    months: Union[Unset, None, int] = UNSET,
    check_type: Union[Unset, None, GetTableDataQualityStatusCheckType] = UNSET,
    check_time_scale: Union[
        Unset, None, GetTableDataQualityStatusCheckTimeScale
    ] = UNSET,
) -> Optional[TableDataQualityStatusModel]:
    """getTableDataQualityStatus

     Read the most recent results of executed data quality checks on the table and return the current
    table's data quality status - the number of failed data quality checks if the table has active data
    quality issues. Also returns the names of data quality checks that did not pass most recently. This
    operation verifies only the status of the most recently executed data quality checks. Previous data
    quality issues are not counted.

    Args:
        connection_name (str):
        schema_name (str):
        table_name (str):
        months (Union[Unset, None, int]):
        check_type (Union[Unset, None, GetTableDataQualityStatusCheckType]):
        check_time_scale (Union[Unset, None, GetTableDataQualityStatusCheckTimeScale]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        TableDataQualityStatusModel
    """

    return sync_detailed(
        connection_name=connection_name,
        schema_name=schema_name,
        table_name=table_name,
        client=client,
        months=months,
        check_type=check_type,
        check_time_scale=check_time_scale,
    ).parsed


async def asyncio_detailed(
    connection_name: str,
    schema_name: str,
    table_name: str,
    *,
    client: Client,
    months: Union[Unset, None, int] = UNSET,
    check_type: Union[Unset, None, GetTableDataQualityStatusCheckType] = UNSET,
    check_time_scale: Union[
        Unset, None, GetTableDataQualityStatusCheckTimeScale
    ] = UNSET,
) -> Response[TableDataQualityStatusModel]:
    """getTableDataQualityStatus

     Read the most recent results of executed data quality checks on the table and return the current
    table's data quality status - the number of failed data quality checks if the table has active data
    quality issues. Also returns the names of data quality checks that did not pass most recently. This
    operation verifies only the status of the most recently executed data quality checks. Previous data
    quality issues are not counted.

    Args:
        connection_name (str):
        schema_name (str):
        table_name (str):
        months (Union[Unset, None, int]):
        check_type (Union[Unset, None, GetTableDataQualityStatusCheckType]):
        check_time_scale (Union[Unset, None, GetTableDataQualityStatusCheckTimeScale]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[TableDataQualityStatusModel]
    """

    kwargs = _get_kwargs(
        connection_name=connection_name,
        schema_name=schema_name,
        table_name=table_name,
        client=client,
        months=months,
        check_type=check_type,
        check_time_scale=check_time_scale,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    connection_name: str,
    schema_name: str,
    table_name: str,
    *,
    client: Client,
    months: Union[Unset, None, int] = UNSET,
    check_type: Union[Unset, None, GetTableDataQualityStatusCheckType] = UNSET,
    check_time_scale: Union[
        Unset, None, GetTableDataQualityStatusCheckTimeScale
    ] = UNSET,
) -> Optional[TableDataQualityStatusModel]:
    """getTableDataQualityStatus

     Read the most recent results of executed data quality checks on the table and return the current
    table's data quality status - the number of failed data quality checks if the table has active data
    quality issues. Also returns the names of data quality checks that did not pass most recently. This
    operation verifies only the status of the most recently executed data quality checks. Previous data
    quality issues are not counted.

    Args:
        connection_name (str):
        schema_name (str):
        table_name (str):
        months (Union[Unset, None, int]):
        check_type (Union[Unset, None, GetTableDataQualityStatusCheckType]):
        check_time_scale (Union[Unset, None, GetTableDataQualityStatusCheckTimeScale]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        TableDataQualityStatusModel
    """

    return (
        await asyncio_detailed(
            connection_name=connection_name,
            schema_name=schema_name,
            table_name=table_name,
            client=client,
            months=months,
            check_type=check_type,
            check_time_scale=check_time_scale,
        )
    ).parsed



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.table_sql_aggregate_expr_check_spec import (
        TableSqlAggregateExprCheckSpec,
    )
    from ..models.table_sql_condition_failed_count_check_spec import (
        TableSqlConditionFailedCountCheckSpec,
    )
    from ..models.table_sql_condition_passed_percent_check_spec import (
        TableSqlConditionPassedPercentCheckSpec,
    )


T = TypeVar("T", bound="TableSqlProfilingChecksSpec")


@attr.s(auto_attribs=True)
class TableSqlProfilingChecksSpec:
    """
    Attributes:
        profile_sql_condition_passed_percent_on_table (Union[Unset, TableSqlConditionPassedPercentCheckSpec]):
        profile_sql_condition_failed_count_on_table (Union[Unset, TableSqlConditionFailedCountCheckSpec]):
        profile_sql_aggregate_expr_table (Union[Unset, TableSqlAggregateExprCheckSpec]):
    """

    profile_sql_condition_passed_percent_on_table: Union[
        Unset, "TableSqlConditionPassedPercentCheckSpec"
    ] = UNSET
    profile_sql_condition_failed_count_on_table: Union[
        Unset, "TableSqlConditionFailedCountCheckSpec"
    ] = UNSET
    profile_sql_aggregate_expr_table: Union[
        Unset, "TableSqlAggregateExprCheckSpec"
    ] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        profile_sql_condition_passed_percent_on_table: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(self.profile_sql_condition_passed_percent_on_table, Unset):
            profile_sql_condition_passed_percent_on_table = (
                self.profile_sql_condition_passed_percent_on_table.to_dict()
            )

        profile_sql_condition_failed_count_on_table: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(self.profile_sql_condition_failed_count_on_table, Unset):
            profile_sql_condition_failed_count_on_table = (
                self.profile_sql_condition_failed_count_on_table.to_dict()
            )

        profile_sql_aggregate_expr_table: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_sql_aggregate_expr_table, Unset):
            profile_sql_aggregate_expr_table = (
                self.profile_sql_aggregate_expr_table.to_dict()
            )

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if profile_sql_condition_passed_percent_on_table is not UNSET:
            field_dict[
                "profile_sql_condition_passed_percent_on_table"
            ] = profile_sql_condition_passed_percent_on_table
        if profile_sql_condition_failed_count_on_table is not UNSET:
            field_dict[
                "profile_sql_condition_failed_count_on_table"
            ] = profile_sql_condition_failed_count_on_table
        if profile_sql_aggregate_expr_table is not UNSET:
            field_dict[
                "profile_sql_aggregate_expr_table"
            ] = profile_sql_aggregate_expr_table

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.table_sql_aggregate_expr_check_spec import (
            TableSqlAggregateExprCheckSpec,
        )
        from ..models.table_sql_condition_failed_count_check_spec import (
            TableSqlConditionFailedCountCheckSpec,
        )
        from ..models.table_sql_condition_passed_percent_check_spec import (
            TableSqlConditionPassedPercentCheckSpec,
        )

        d = src_dict.copy()
        _profile_sql_condition_passed_percent_on_table = d.pop(
            "profile_sql_condition_passed_percent_on_table", UNSET
        )
        profile_sql_condition_passed_percent_on_table: Union[
            Unset, TableSqlConditionPassedPercentCheckSpec
        ]
        if isinstance(_profile_sql_condition_passed_percent_on_table, Unset):
            profile_sql_condition_passed_percent_on_table = UNSET
        else:
            profile_sql_condition_passed_percent_on_table = (
                TableSqlConditionPassedPercentCheckSpec.from_dict(
                    _profile_sql_condition_passed_percent_on_table
                )
            )

        _profile_sql_condition_failed_count_on_table = d.pop(
            "profile_sql_condition_failed_count_on_table", UNSET
        )
        profile_sql_condition_failed_count_on_table: Union[
            Unset, TableSqlConditionFailedCountCheckSpec
        ]
        if isinstance(_profile_sql_condition_failed_count_on_table, Unset):
            profile_sql_condition_failed_count_on_table = UNSET
        else:
            profile_sql_condition_failed_count_on_table = (
                TableSqlConditionFailedCountCheckSpec.from_dict(
                    _profile_sql_condition_failed_count_on_table
                )
            )

        _profile_sql_aggregate_expr_table = d.pop(
            "profile_sql_aggregate_expr_table", UNSET
        )
        profile_sql_aggregate_expr_table: Union[Unset, TableSqlAggregateExprCheckSpec]
        if isinstance(_profile_sql_aggregate_expr_table, Unset):
            profile_sql_aggregate_expr_table = UNSET
        else:
            profile_sql_aggregate_expr_table = TableSqlAggregateExprCheckSpec.from_dict(
                _profile_sql_aggregate_expr_table
            )

        table_sql_profiling_checks_spec = cls(
            profile_sql_condition_passed_percent_on_table=profile_sql_condition_passed_percent_on_table,
            profile_sql_condition_failed_count_on_table=profile_sql_condition_failed_count_on_table,
            profile_sql_aggregate_expr_table=profile_sql_aggregate_expr_table,
        )

        table_sql_profiling_checks_spec.additional_properties = d
        return table_sql_profiling_checks_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from http import HTTPStatus
from typing import Any, Dict, List, Optional, Union

import httpx

from ... import errors
from ...client import Client
from ...models.check_template import CheckTemplate
from ...models.get_schema_partitioned_checks_templates_check_target import (
    GetSchemaPartitionedChecksTemplatesCheckTarget,
)
from ...models.get_schema_partitioned_checks_templates_time_scale import (
    GetSchemaPartitionedChecksTemplatesTimeScale,
)
from ...types import UNSET, Response, Unset


def _get_kwargs(
    connection_name: str,
    schema_name: str,
    time_scale: GetSchemaPartitionedChecksTemplatesTimeScale,
    *,
    client: Client,
    check_target: Union[
        Unset, None, GetSchemaPartitionedChecksTemplatesCheckTarget
    ] = UNSET,
    check_category: Union[Unset, None, str] = UNSET,
    check_name: Union[Unset, None, str] = UNSET,
) -> Dict[str, Any]:
    url = "{}api/connections/{connectionName}/schemas/{schemaName}/bulkenable/partitioned/{timeScale}".format(
        client.base_url,
        connectionName=connection_name,
        schemaName=schema_name,
        timeScale=time_scale,
    )

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {}
    json_check_target: Union[Unset, None, str] = UNSET
    if not isinstance(check_target, Unset):
        json_check_target = check_target.value if check_target else None

    params["checkTarget"] = json_check_target

    params["checkCategory"] = check_category

    params["checkName"] = check_name

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "method": "get",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "follow_redirects": client.follow_redirects,
        "params": params,
    }


def _parse_response(
    *, client: Client, response: httpx.Response
) -> Optional[List["CheckTemplate"]]:
    if response.status_code == HTTPStatus.OK:
        response_200 = []
        _response_200 = response.json()
        for response_200_item_data in _response_200:
            response_200_item = CheckTemplate.from_dict(response_200_item_data)

            response_200.append(response_200_item)

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Client, response: httpx.Response
) -> Response[List["CheckTemplate"]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    connection_name: str,
    schema_name: str,
    time_scale: GetSchemaPartitionedChecksTemplatesTimeScale,
    *,
    client: Client,
    check_target: Union[
        Unset, None, GetSchemaPartitionedChecksTemplatesCheckTarget
    ] = UNSET,
    check_category: Union[Unset, None, str] = UNSET,
    check_name: Union[Unset, None, str] = UNSET,
) -> Response[List["CheckTemplate"]]:
    """getSchemaPartitionedChecksTemplates

     Return available data quality checks on a requested schema.

    Args:
        connection_name (str):
        schema_name (str):
        time_scale (GetSchemaPartitionedChecksTemplatesTimeScale):
        check_target (Union[Unset, None, GetSchemaPartitionedChecksTemplatesCheckTarget]):
        check_category (Union[Unset, None, str]):
        check_name (Union[Unset, None, str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[List['CheckTemplate']]
    """

    kwargs = _get_kwargs(
        connection_name=connection_name,
        schema_name=schema_name,
        time_scale=time_scale,
        client=client,
        check_target=check_target,
        check_category=check_category,
        check_name=check_name,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    connection_name: str,
    schema_name: str,
    time_scale: GetSchemaPartitionedChecksTemplatesTimeScale,
    *,
    client: Client,
    check_target: Union[
        Unset, None, GetSchemaPartitionedChecksTemplatesCheckTarget
    ] = UNSET,
    check_category: Union[Unset, None, str] = UNSET,
    check_name: Union[Unset, None, str] = UNSET,
) -> Optional[List["CheckTemplate"]]:
    """getSchemaPartitionedChecksTemplates

     Return available data quality checks on a requested schema.

    Args:
        connection_name (str):
        schema_name (str):
        time_scale (GetSchemaPartitionedChecksTemplatesTimeScale):
        check_target (Union[Unset, None, GetSchemaPartitionedChecksTemplatesCheckTarget]):
        check_category (Union[Unset, None, str]):
        check_name (Union[Unset, None, str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        List['CheckTemplate']
    """

    return sync_detailed(
        connection_name=connection_name,
        schema_name=schema_name,
        time_scale=time_scale,
        client=client,
        check_target=check_target,
        check_category=check_category,
        check_name=check_name,
    ).parsed


async def asyncio_detailed(
    connection_name: str,
    schema_name: str,
    time_scale: GetSchemaPartitionedChecksTemplatesTimeScale,
    *,
    client: Client,
    check_target: Union[
        Unset, None, GetSchemaPartitionedChecksTemplatesCheckTarget
    ] = UNSET,
    check_category: Union[Unset, None, str] = UNSET,
    check_name: Union[Unset, None, str] = UNSET,
) -> Response[List["CheckTemplate"]]:
    """getSchemaPartitionedChecksTemplates

     Return available data quality checks on a requested schema.

    Args:
        connection_name (str):
        schema_name (str):
        time_scale (GetSchemaPartitionedChecksTemplatesTimeScale):
        check_target (Union[Unset, None, GetSchemaPartitionedChecksTemplatesCheckTarget]):
        check_category (Union[Unset, None, str]):
        check_name (Union[Unset, None, str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[List['CheckTemplate']]
    """

    kwargs = _get_kwargs(
        connection_name=connection_name,
        schema_name=schema_name,
        time_scale=time_scale,
        client=client,
        check_target=check_target,
        check_category=check_category,
        check_name=check_name,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    connection_name: str,
    schema_name: str,
    time_scale: GetSchemaPartitionedChecksTemplatesTimeScale,
    *,
    client: Client,
    check_target: Union[
        Unset, None, GetSchemaPartitionedChecksTemplatesCheckTarget
    ] = UNSET,
    check_category: Union[Unset, None, str] = UNSET,
    check_name: Union[Unset, None, str] = UNSET,
) -> Optional[List["CheckTemplate"]]:
    """getSchemaPartitionedChecksTemplates

     Return available data quality checks on a requested schema.

    Args:
        connection_name (str):
        schema_name (str):
        time_scale (GetSchemaPartitionedChecksTemplatesTimeScale):
        check_target (Union[Unset, None, GetSchemaPartitionedChecksTemplatesCheckTarget]):
        check_category (Union[Unset, None, str]):
        check_name (Union[Unset, None, str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        List['CheckTemplate']
    """

    return (
        await asyncio_detailed(
            connection_name=connection_name,
            schema_name=schema_name,
            time_scale=time_scale,
            client=client,
            check_target=check_target,
            check_category=check_category,
            check_name=check_name,
        )
    ).parsed



from enum import Enum


class CheckModelConfigurationRequirementsErrorsItem(str, Enum):
    MISSING_EVENT_AND_INGESTION_COLUMNS = "missing_event_and_ingestion_columns"
    MISSING_EVENT_TIMESTAMP_COLUMN = "missing_event_timestamp_column"
    MISSING_INGESTION_TIMESTAMP_COLUMN = "missing_ingestion_timestamp_column"
    MISSING_TIME_PERIOD_PARTITIONING_COLUMN = "missing_time_period_partitioning_column"

    def __str__(self) -> str:
        return str(self.value)



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.column_anomaly_differencing_sum_30_days_check_spec import (
        ColumnAnomalyDifferencingSum30DaysCheckSpec,
    )
    from ..models.column_anomaly_differencing_sum_check_spec import (
        ColumnAnomalyDifferencingSumCheckSpec,
    )
    from ..models.column_anomaly_stationary_mean_30_days_check_spec import (
        ColumnAnomalyStationaryMean30DaysCheckSpec,
    )
    from ..models.column_anomaly_stationary_mean_check_spec import (
        ColumnAnomalyStationaryMeanCheckSpec,
    )
    from ..models.column_anomaly_stationary_median_30_days_check_spec import (
        ColumnAnomalyStationaryMedian30DaysCheckSpec,
    )
    from ..models.column_anomaly_stationary_median_check_spec import (
        ColumnAnomalyStationaryMedianCheckSpec,
    )
    from ..models.column_change_mean_check_spec import ColumnChangeMeanCheckSpec
    from ..models.column_change_mean_since_7_days_check_spec import (
        ColumnChangeMeanSince7DaysCheckSpec,
    )
    from ..models.column_change_mean_since_30_days_check_spec import (
        ColumnChangeMeanSince30DaysCheckSpec,
    )
    from ..models.column_change_mean_since_yesterday_check_spec import (
        ColumnChangeMeanSinceYesterdayCheckSpec,
    )
    from ..models.column_change_median_check_spec import ColumnChangeMedianCheckSpec
    from ..models.column_change_median_since_7_days_check_spec import (
        ColumnChangeMedianSince7DaysCheckSpec,
    )
    from ..models.column_change_median_since_30_days_check_spec import (
        ColumnChangeMedianSince30DaysCheckSpec,
    )
    from ..models.column_change_median_since_yesterday_check_spec import (
        ColumnChangeMedianSinceYesterdayCheckSpec,
    )
    from ..models.column_change_sum_check_spec import ColumnChangeSumCheckSpec
    from ..models.column_change_sum_since_7_days_check_spec import (
        ColumnChangeSumSince7DaysCheckSpec,
    )
    from ..models.column_change_sum_since_30_days_check_spec import (
        ColumnChangeSumSince30DaysCheckSpec,
    )
    from ..models.column_change_sum_since_yesterday_check_spec import (
        ColumnChangeSumSinceYesterdayCheckSpec,
    )


T = TypeVar("T", bound="ColumnAnomalyDailyRecurringChecksSpec")


@attr.s(auto_attribs=True)
class ColumnAnomalyDailyRecurringChecksSpec:
    """
    Attributes:
        daily_mean_change (Union[Unset, ColumnChangeMeanCheckSpec]):
        daily_mean_change_yesterday (Union[Unset, ColumnChangeMeanSinceYesterdayCheckSpec]):
        daily_median_change (Union[Unset, ColumnChangeMedianCheckSpec]):
        daily_median_change_yesterday (Union[Unset, ColumnChangeMedianSinceYesterdayCheckSpec]):
        daily_sum_change (Union[Unset, ColumnChangeSumCheckSpec]):
        daily_sum_change_yesterday (Union[Unset, ColumnChangeSumSinceYesterdayCheckSpec]):
        daily_mean_anomaly_stationary_30_days (Union[Unset, ColumnAnomalyStationaryMean30DaysCheckSpec]):
        daily_mean_anomaly_stationary (Union[Unset, ColumnAnomalyStationaryMeanCheckSpec]):
        daily_median_anomaly_stationary_30_days (Union[Unset, ColumnAnomalyStationaryMedian30DaysCheckSpec]):
        daily_median_anomaly_stationary (Union[Unset, ColumnAnomalyStationaryMedianCheckSpec]):
        daily_sum_anomaly_differencing_30_days (Union[Unset, ColumnAnomalyDifferencingSum30DaysCheckSpec]):
        daily_sum_anomaly_differencing (Union[Unset, ColumnAnomalyDifferencingSumCheckSpec]):
        daily_mean_change_7_days (Union[Unset, ColumnChangeMeanSince7DaysCheckSpec]):
        daily_mean_change_30_days (Union[Unset, ColumnChangeMeanSince30DaysCheckSpec]):
        daily_median_change_7_days (Union[Unset, ColumnChangeMedianSince7DaysCheckSpec]):
        daily_median_change_30_days (Union[Unset, ColumnChangeMedianSince30DaysCheckSpec]):
        daily_sum_change_7_days (Union[Unset, ColumnChangeSumSince7DaysCheckSpec]):
        daily_sum_change_30_days (Union[Unset, ColumnChangeSumSince30DaysCheckSpec]):
    """

    daily_mean_change: Union[Unset, "ColumnChangeMeanCheckSpec"] = UNSET
    daily_mean_change_yesterday: Union[
        Unset, "ColumnChangeMeanSinceYesterdayCheckSpec"
    ] = UNSET
    daily_median_change: Union[Unset, "ColumnChangeMedianCheckSpec"] = UNSET
    daily_median_change_yesterday: Union[
        Unset, "ColumnChangeMedianSinceYesterdayCheckSpec"
    ] = UNSET
    daily_sum_change: Union[Unset, "ColumnChangeSumCheckSpec"] = UNSET
    daily_sum_change_yesterday: Union[
        Unset, "ColumnChangeSumSinceYesterdayCheckSpec"
    ] = UNSET
    daily_mean_anomaly_stationary_30_days: Union[
        Unset, "ColumnAnomalyStationaryMean30DaysCheckSpec"
    ] = UNSET
    daily_mean_anomaly_stationary: Union[
        Unset, "ColumnAnomalyStationaryMeanCheckSpec"
    ] = UNSET
    daily_median_anomaly_stationary_30_days: Union[
        Unset, "ColumnAnomalyStationaryMedian30DaysCheckSpec"
    ] = UNSET
    daily_median_anomaly_stationary: Union[
        Unset, "ColumnAnomalyStationaryMedianCheckSpec"
    ] = UNSET
    daily_sum_anomaly_differencing_30_days: Union[
        Unset, "ColumnAnomalyDifferencingSum30DaysCheckSpec"
    ] = UNSET
    daily_sum_anomaly_differencing: Union[
        Unset, "ColumnAnomalyDifferencingSumCheckSpec"
    ] = UNSET
    daily_mean_change_7_days: Union[
        Unset, "ColumnChangeMeanSince7DaysCheckSpec"
    ] = UNSET
    daily_mean_change_30_days: Union[
        Unset, "ColumnChangeMeanSince30DaysCheckSpec"
    ] = UNSET
    daily_median_change_7_days: Union[
        Unset, "ColumnChangeMedianSince7DaysCheckSpec"
    ] = UNSET
    daily_median_change_30_days: Union[
        Unset, "ColumnChangeMedianSince30DaysCheckSpec"
    ] = UNSET
    daily_sum_change_7_days: Union[Unset, "ColumnChangeSumSince7DaysCheckSpec"] = UNSET
    daily_sum_change_30_days: Union[
        Unset, "ColumnChangeSumSince30DaysCheckSpec"
    ] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        daily_mean_change: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.daily_mean_change, Unset):
            daily_mean_change = self.daily_mean_change.to_dict()

        daily_mean_change_yesterday: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.daily_mean_change_yesterday, Unset):
            daily_mean_change_yesterday = self.daily_mean_change_yesterday.to_dict()

        daily_median_change: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.daily_median_change, Unset):
            daily_median_change = self.daily_median_change.to_dict()

        daily_median_change_yesterday: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.daily_median_change_yesterday, Unset):
            daily_median_change_yesterday = self.daily_median_change_yesterday.to_dict()

        daily_sum_change: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.daily_sum_change, Unset):
            daily_sum_change = self.daily_sum_change.to_dict()

        daily_sum_change_yesterday: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.daily_sum_change_yesterday, Unset):
            daily_sum_change_yesterday = self.daily_sum_change_yesterday.to_dict()

        daily_mean_anomaly_stationary_30_days: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.daily_mean_anomaly_stationary_30_days, Unset):
            daily_mean_anomaly_stationary_30_days = (
                self.daily_mean_anomaly_stationary_30_days.to_dict()
            )

        daily_mean_anomaly_stationary: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.daily_mean_anomaly_stationary, Unset):
            daily_mean_anomaly_stationary = self.daily_mean_anomaly_stationary.to_dict()

        daily_median_anomaly_stationary_30_days: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.daily_median_anomaly_stationary_30_days, Unset):
            daily_median_anomaly_stationary_30_days = (
                self.daily_median_anomaly_stationary_30_days.to_dict()
            )

        daily_median_anomaly_stationary: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.daily_median_anomaly_stationary, Unset):
            daily_median_anomaly_stationary = (
                self.daily_median_anomaly_stationary.to_dict()
            )

        daily_sum_anomaly_differencing_30_days: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.daily_sum_anomaly_differencing_30_days, Unset):
            daily_sum_anomaly_differencing_30_days = (
                self.daily_sum_anomaly_differencing_30_days.to_dict()
            )

        daily_sum_anomaly_differencing: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.daily_sum_anomaly_differencing, Unset):
            daily_sum_anomaly_differencing = (
                self.daily_sum_anomaly_differencing.to_dict()
            )

        daily_mean_change_7_days: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.daily_mean_change_7_days, Unset):
            daily_mean_change_7_days = self.daily_mean_change_7_days.to_dict()

        daily_mean_change_30_days: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.daily_mean_change_30_days, Unset):
            daily_mean_change_30_days = self.daily_mean_change_30_days.to_dict()

        daily_median_change_7_days: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.daily_median_change_7_days, Unset):
            daily_median_change_7_days = self.daily_median_change_7_days.to_dict()

        daily_median_change_30_days: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.daily_median_change_30_days, Unset):
            daily_median_change_30_days = self.daily_median_change_30_days.to_dict()

        daily_sum_change_7_days: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.daily_sum_change_7_days, Unset):
            daily_sum_change_7_days = self.daily_sum_change_7_days.to_dict()

        daily_sum_change_30_days: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.daily_sum_change_30_days, Unset):
            daily_sum_change_30_days = self.daily_sum_change_30_days.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if daily_mean_change is not UNSET:
            field_dict["daily_mean_change"] = daily_mean_change
        if daily_mean_change_yesterday is not UNSET:
            field_dict["daily_mean_change_yesterday"] = daily_mean_change_yesterday
        if daily_median_change is not UNSET:
            field_dict["daily_median_change"] = daily_median_change
        if daily_median_change_yesterday is not UNSET:
            field_dict["daily_median_change_yesterday"] = daily_median_change_yesterday
        if daily_sum_change is not UNSET:
            field_dict["daily_sum_change"] = daily_sum_change
        if daily_sum_change_yesterday is not UNSET:
            field_dict["daily_sum_change_yesterday"] = daily_sum_change_yesterday
        if daily_mean_anomaly_stationary_30_days is not UNSET:
            field_dict[
                "daily_mean_anomaly_stationary_30_days"
            ] = daily_mean_anomaly_stationary_30_days
        if daily_mean_anomaly_stationary is not UNSET:
            field_dict["daily_mean_anomaly_stationary"] = daily_mean_anomaly_stationary
        if daily_median_anomaly_stationary_30_days is not UNSET:
            field_dict[
                "daily_median_anomaly_stationary_30_days"
            ] = daily_median_anomaly_stationary_30_days
        if daily_median_anomaly_stationary is not UNSET:
            field_dict[
                "daily_median_anomaly_stationary"
            ] = daily_median_anomaly_stationary
        if daily_sum_anomaly_differencing_30_days is not UNSET:
            field_dict[
                "daily_sum_anomaly_differencing_30_days"
            ] = daily_sum_anomaly_differencing_30_days
        if daily_sum_anomaly_differencing is not UNSET:
            field_dict[
                "daily_sum_anomaly_differencing"
            ] = daily_sum_anomaly_differencing
        if daily_mean_change_7_days is not UNSET:
            field_dict["daily_mean_change_7_days"] = daily_mean_change_7_days
        if daily_mean_change_30_days is not UNSET:
            field_dict["daily_mean_change_30_days"] = daily_mean_change_30_days
        if daily_median_change_7_days is not UNSET:
            field_dict["daily_median_change_7_days"] = daily_median_change_7_days
        if daily_median_change_30_days is not UNSET:
            field_dict["daily_median_change_30_days"] = daily_median_change_30_days
        if daily_sum_change_7_days is not UNSET:
            field_dict["daily_sum_change_7_days"] = daily_sum_change_7_days
        if daily_sum_change_30_days is not UNSET:
            field_dict["daily_sum_change_30_days"] = daily_sum_change_30_days

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.column_anomaly_differencing_sum_30_days_check_spec import (
            ColumnAnomalyDifferencingSum30DaysCheckSpec,
        )
        from ..models.column_anomaly_differencing_sum_check_spec import (
            ColumnAnomalyDifferencingSumCheckSpec,
        )
        from ..models.column_anomaly_stationary_mean_30_days_check_spec import (
            ColumnAnomalyStationaryMean30DaysCheckSpec,
        )
        from ..models.column_anomaly_stationary_mean_check_spec import (
            ColumnAnomalyStationaryMeanCheckSpec,
        )
        from ..models.column_anomaly_stationary_median_30_days_check_spec import (
            ColumnAnomalyStationaryMedian30DaysCheckSpec,
        )
        from ..models.column_anomaly_stationary_median_check_spec import (
            ColumnAnomalyStationaryMedianCheckSpec,
        )
        from ..models.column_change_mean_check_spec import ColumnChangeMeanCheckSpec
        from ..models.column_change_mean_since_7_days_check_spec import (
            ColumnChangeMeanSince7DaysCheckSpec,
        )
        from ..models.column_change_mean_since_30_days_check_spec import (
            ColumnChangeMeanSince30DaysCheckSpec,
        )
        from ..models.column_change_mean_since_yesterday_check_spec import (
            ColumnChangeMeanSinceYesterdayCheckSpec,
        )
        from ..models.column_change_median_check_spec import ColumnChangeMedianCheckSpec
        from ..models.column_change_median_since_7_days_check_spec import (
            ColumnChangeMedianSince7DaysCheckSpec,
        )
        from ..models.column_change_median_since_30_days_check_spec import (
            ColumnChangeMedianSince30DaysCheckSpec,
        )
        from ..models.column_change_median_since_yesterday_check_spec import (
            ColumnChangeMedianSinceYesterdayCheckSpec,
        )
        from ..models.column_change_sum_check_spec import ColumnChangeSumCheckSpec
        from ..models.column_change_sum_since_7_days_check_spec import (
            ColumnChangeSumSince7DaysCheckSpec,
        )
        from ..models.column_change_sum_since_30_days_check_spec import (
            ColumnChangeSumSince30DaysCheckSpec,
        )
        from ..models.column_change_sum_since_yesterday_check_spec import (
            ColumnChangeSumSinceYesterdayCheckSpec,
        )

        d = src_dict.copy()
        _daily_mean_change = d.pop("daily_mean_change", UNSET)
        daily_mean_change: Union[Unset, ColumnChangeMeanCheckSpec]
        if isinstance(_daily_mean_change, Unset):
            daily_mean_change = UNSET
        else:
            daily_mean_change = ColumnChangeMeanCheckSpec.from_dict(_daily_mean_change)

        _daily_mean_change_yesterday = d.pop("daily_mean_change_yesterday", UNSET)
        daily_mean_change_yesterday: Union[
            Unset, ColumnChangeMeanSinceYesterdayCheckSpec
        ]
        if isinstance(_daily_mean_change_yesterday, Unset):
            daily_mean_change_yesterday = UNSET
        else:
            daily_mean_change_yesterday = (
                ColumnChangeMeanSinceYesterdayCheckSpec.from_dict(
                    _daily_mean_change_yesterday
                )
            )

        _daily_median_change = d.pop("daily_median_change", UNSET)
        daily_median_change: Union[Unset, ColumnChangeMedianCheckSpec]
        if isinstance(_daily_median_change, Unset):
            daily_median_change = UNSET
        else:
            daily_median_change = ColumnChangeMedianCheckSpec.from_dict(
                _daily_median_change
            )

        _daily_median_change_yesterday = d.pop("daily_median_change_yesterday", UNSET)
        daily_median_change_yesterday: Union[
            Unset, ColumnChangeMedianSinceYesterdayCheckSpec
        ]
        if isinstance(_daily_median_change_yesterday, Unset):
            daily_median_change_yesterday = UNSET
        else:
            daily_median_change_yesterday = (
                ColumnChangeMedianSinceYesterdayCheckSpec.from_dict(
                    _daily_median_change_yesterday
                )
            )

        _daily_sum_change = d.pop("daily_sum_change", UNSET)
        daily_sum_change: Union[Unset, ColumnChangeSumCheckSpec]
        if isinstance(_daily_sum_change, Unset):
            daily_sum_change = UNSET
        else:
            daily_sum_change = ColumnChangeSumCheckSpec.from_dict(_daily_sum_change)

        _daily_sum_change_yesterday = d.pop("daily_sum_change_yesterday", UNSET)
        daily_sum_change_yesterday: Union[Unset, ColumnChangeSumSinceYesterdayCheckSpec]
        if isinstance(_daily_sum_change_yesterday, Unset):
            daily_sum_change_yesterday = UNSET
        else:
            daily_sum_change_yesterday = (
                ColumnChangeSumSinceYesterdayCheckSpec.from_dict(
                    _daily_sum_change_yesterday
                )
            )

        _daily_mean_anomaly_stationary_30_days = d.pop(
            "daily_mean_anomaly_stationary_30_days", UNSET
        )
        daily_mean_anomaly_stationary_30_days: Union[
            Unset, ColumnAnomalyStationaryMean30DaysCheckSpec
        ]
        if isinstance(_daily_mean_anomaly_stationary_30_days, Unset):
            daily_mean_anomaly_stationary_30_days = UNSET
        else:
            daily_mean_anomaly_stationary_30_days = (
                ColumnAnomalyStationaryMean30DaysCheckSpec.from_dict(
                    _daily_mean_anomaly_stationary_30_days
                )
            )

        _daily_mean_anomaly_stationary = d.pop("daily_mean_anomaly_stationary", UNSET)
        daily_mean_anomaly_stationary: Union[
            Unset, ColumnAnomalyStationaryMeanCheckSpec
        ]
        if isinstance(_daily_mean_anomaly_stationary, Unset):
            daily_mean_anomaly_stationary = UNSET
        else:
            daily_mean_anomaly_stationary = (
                ColumnAnomalyStationaryMeanCheckSpec.from_dict(
                    _daily_mean_anomaly_stationary
                )
            )

        _daily_median_anomaly_stationary_30_days = d.pop(
            "daily_median_anomaly_stationary_30_days", UNSET
        )
        daily_median_anomaly_stationary_30_days: Union[
            Unset, ColumnAnomalyStationaryMedian30DaysCheckSpec
        ]
        if isinstance(_daily_median_anomaly_stationary_30_days, Unset):
            daily_median_anomaly_stationary_30_days = UNSET
        else:
            daily_median_anomaly_stationary_30_days = (
                ColumnAnomalyStationaryMedian30DaysCheckSpec.from_dict(
                    _daily_median_anomaly_stationary_30_days
                )
            )

        _daily_median_anomaly_stationary = d.pop(
            "daily_median_anomaly_stationary", UNSET
        )
        daily_median_anomaly_stationary: Union[
            Unset, ColumnAnomalyStationaryMedianCheckSpec
        ]
        if isinstance(_daily_median_anomaly_stationary, Unset):
            daily_median_anomaly_stationary = UNSET
        else:
            daily_median_anomaly_stationary = (
                ColumnAnomalyStationaryMedianCheckSpec.from_dict(
                    _daily_median_anomaly_stationary
                )
            )

        _daily_sum_anomaly_differencing_30_days = d.pop(
            "daily_sum_anomaly_differencing_30_days", UNSET
        )
        daily_sum_anomaly_differencing_30_days: Union[
            Unset, ColumnAnomalyDifferencingSum30DaysCheckSpec
        ]
        if isinstance(_daily_sum_anomaly_differencing_30_days, Unset):
            daily_sum_anomaly_differencing_30_days = UNSET
        else:
            daily_sum_anomaly_differencing_30_days = (
                ColumnAnomalyDifferencingSum30DaysCheckSpec.from_dict(
                    _daily_sum_anomaly_differencing_30_days
                )
            )

        _daily_sum_anomaly_differencing = d.pop("daily_sum_anomaly_differencing", UNSET)
        daily_sum_anomaly_differencing: Union[
            Unset, ColumnAnomalyDifferencingSumCheckSpec
        ]
        if isinstance(_daily_sum_anomaly_differencing, Unset):
            daily_sum_anomaly_differencing = UNSET
        else:
            daily_sum_anomaly_differencing = (
                ColumnAnomalyDifferencingSumCheckSpec.from_dict(
                    _daily_sum_anomaly_differencing
                )
            )

        _daily_mean_change_7_days = d.pop("daily_mean_change_7_days", UNSET)
        daily_mean_change_7_days: Union[Unset, ColumnChangeMeanSince7DaysCheckSpec]
        if isinstance(_daily_mean_change_7_days, Unset):
            daily_mean_change_7_days = UNSET
        else:
            daily_mean_change_7_days = ColumnChangeMeanSince7DaysCheckSpec.from_dict(
                _daily_mean_change_7_days
            )

        _daily_mean_change_30_days = d.pop("daily_mean_change_30_days", UNSET)
        daily_mean_change_30_days: Union[Unset, ColumnChangeMeanSince30DaysCheckSpec]
        if isinstance(_daily_mean_change_30_days, Unset):
            daily_mean_change_30_days = UNSET
        else:
            daily_mean_change_30_days = ColumnChangeMeanSince30DaysCheckSpec.from_dict(
                _daily_mean_change_30_days
            )

        _daily_median_change_7_days = d.pop("daily_median_change_7_days", UNSET)
        daily_median_change_7_days: Union[Unset, ColumnChangeMedianSince7DaysCheckSpec]
        if isinstance(_daily_median_change_7_days, Unset):
            daily_median_change_7_days = UNSET
        else:
            daily_median_change_7_days = (
                ColumnChangeMedianSince7DaysCheckSpec.from_dict(
                    _daily_median_change_7_days
                )
            )

        _daily_median_change_30_days = d.pop("daily_median_change_30_days", UNSET)
        daily_median_change_30_days: Union[
            Unset, ColumnChangeMedianSince30DaysCheckSpec
        ]
        if isinstance(_daily_median_change_30_days, Unset):
            daily_median_change_30_days = UNSET
        else:
            daily_median_change_30_days = (
                ColumnChangeMedianSince30DaysCheckSpec.from_dict(
                    _daily_median_change_30_days
                )
            )

        _daily_sum_change_7_days = d.pop("daily_sum_change_7_days", UNSET)
        daily_sum_change_7_days: Union[Unset, ColumnChangeSumSince7DaysCheckSpec]
        if isinstance(_daily_sum_change_7_days, Unset):
            daily_sum_change_7_days = UNSET
        else:
            daily_sum_change_7_days = ColumnChangeSumSince7DaysCheckSpec.from_dict(
                _daily_sum_change_7_days
            )

        _daily_sum_change_30_days = d.pop("daily_sum_change_30_days", UNSET)
        daily_sum_change_30_days: Union[Unset, ColumnChangeSumSince30DaysCheckSpec]
        if isinstance(_daily_sum_change_30_days, Unset):
            daily_sum_change_30_days = UNSET
        else:
            daily_sum_change_30_days = ColumnChangeSumSince30DaysCheckSpec.from_dict(
                _daily_sum_change_30_days
            )

        column_anomaly_daily_recurring_checks_spec = cls(
            daily_mean_change=daily_mean_change,
            daily_mean_change_yesterday=daily_mean_change_yesterday,
            daily_median_change=daily_median_change,
            daily_median_change_yesterday=daily_median_change_yesterday,
            daily_sum_change=daily_sum_change,
            daily_sum_change_yesterday=daily_sum_change_yesterday,
            daily_mean_anomaly_stationary_30_days=daily_mean_anomaly_stationary_30_days,
            daily_mean_anomaly_stationary=daily_mean_anomaly_stationary,
            daily_median_anomaly_stationary_30_days=daily_median_anomaly_stationary_30_days,
            daily_median_anomaly_stationary=daily_median_anomaly_stationary,
            daily_sum_anomaly_differencing_30_days=daily_sum_anomaly_differencing_30_days,
            daily_sum_anomaly_differencing=daily_sum_anomaly_differencing,
            daily_mean_change_7_days=daily_mean_change_7_days,
            daily_mean_change_30_days=daily_mean_change_30_days,
            daily_median_change_7_days=daily_median_change_7_days,
            daily_median_change_30_days=daily_median_change_30_days,
            daily_sum_change_7_days=daily_sum_change_7_days,
            daily_sum_change_30_days=daily_sum_change_30_days,
        )

        column_anomaly_daily_recurring_checks_spec.additional_properties = d
        return column_anomaly_daily_recurring_checks_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..models.statistics_collector_search_filters_target import (
    StatisticsCollectorSearchFiltersTarget,
)
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.hierarchy_id_model import HierarchyIdModel


T = TypeVar("T", bound="StatisticsCollectorSearchFilters")


@attr.s(auto_attribs=True)
class StatisticsCollectorSearchFilters:
    """
    Attributes:
        connection_name (Union[Unset, str]):
        schema_table_name (Union[Unset, str]):
        enabled (Union[Unset, bool]):
        tags (Union[Unset, List[str]]):
        labels (Union[Unset, List[str]]):
        column_name (Union[Unset, str]):
        collector_name (Union[Unset, str]):
        sensor_name (Union[Unset, str]):
        collector_category (Union[Unset, str]):
        target (Union[Unset, StatisticsCollectorSearchFiltersTarget]):
        collectors_hierarchy_ids_models (Union[Unset, List['HierarchyIdModel']]):
    """

    connection_name: Union[Unset, str] = UNSET
    schema_table_name: Union[Unset, str] = UNSET
    enabled: Union[Unset, bool] = UNSET
    tags: Union[Unset, List[str]] = UNSET
    labels: Union[Unset, List[str]] = UNSET
    column_name: Union[Unset, str] = UNSET
    collector_name: Union[Unset, str] = UNSET
    sensor_name: Union[Unset, str] = UNSET
    collector_category: Union[Unset, str] = UNSET
    target: Union[Unset, StatisticsCollectorSearchFiltersTarget] = UNSET
    collectors_hierarchy_ids_models: Union[Unset, List["HierarchyIdModel"]] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        connection_name = self.connection_name
        schema_table_name = self.schema_table_name
        enabled = self.enabled
        tags: Union[Unset, List[str]] = UNSET
        if not isinstance(self.tags, Unset):
            tags = self.tags

        labels: Union[Unset, List[str]] = UNSET
        if not isinstance(self.labels, Unset):
            labels = self.labels

        column_name = self.column_name
        collector_name = self.collector_name
        sensor_name = self.sensor_name
        collector_category = self.collector_category
        target: Union[Unset, str] = UNSET
        if not isinstance(self.target, Unset):
            target = self.target.value

        collectors_hierarchy_ids_models: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.collectors_hierarchy_ids_models, Unset):
            collectors_hierarchy_ids_models = []
            for (
                collectors_hierarchy_ids_models_item_data
            ) in self.collectors_hierarchy_ids_models:
                collectors_hierarchy_ids_models_item = (
                    collectors_hierarchy_ids_models_item_data.to_dict()
                )

                collectors_hierarchy_ids_models.append(
                    collectors_hierarchy_ids_models_item
                )

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if connection_name is not UNSET:
            field_dict["connectionName"] = connection_name
        if schema_table_name is not UNSET:
            field_dict["schemaTableName"] = schema_table_name
        if enabled is not UNSET:
            field_dict["enabled"] = enabled
        if tags is not UNSET:
            field_dict["tags"] = tags
        if labels is not UNSET:
            field_dict["labels"] = labels
        if column_name is not UNSET:
            field_dict["columnName"] = column_name
        if collector_name is not UNSET:
            field_dict["collectorName"] = collector_name
        if sensor_name is not UNSET:
            field_dict["sensorName"] = sensor_name
        if collector_category is not UNSET:
            field_dict["collectorCategory"] = collector_category
        if target is not UNSET:
            field_dict["target"] = target
        if collectors_hierarchy_ids_models is not UNSET:
            field_dict["collectorsHierarchyIdsModels"] = collectors_hierarchy_ids_models

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.hierarchy_id_model import HierarchyIdModel

        d = src_dict.copy()
        connection_name = d.pop("connectionName", UNSET)

        schema_table_name = d.pop("schemaTableName", UNSET)

        enabled = d.pop("enabled", UNSET)

        tags = cast(List[str], d.pop("tags", UNSET))

        labels = cast(List[str], d.pop("labels", UNSET))

        column_name = d.pop("columnName", UNSET)

        collector_name = d.pop("collectorName", UNSET)

        sensor_name = d.pop("sensorName", UNSET)

        collector_category = d.pop("collectorCategory", UNSET)

        _target = d.pop("target", UNSET)
        target: Union[Unset, StatisticsCollectorSearchFiltersTarget]
        if isinstance(_target, Unset):
            target = UNSET
        else:
            target = StatisticsCollectorSearchFiltersTarget(_target)

        collectors_hierarchy_ids_models = []
        _collectors_hierarchy_ids_models = d.pop("collectorsHierarchyIdsModels", UNSET)
        for collectors_hierarchy_ids_models_item_data in (
            _collectors_hierarchy_ids_models or []
        ):
            collectors_hierarchy_ids_models_item = HierarchyIdModel.from_dict(
                collectors_hierarchy_ids_models_item_data
            )

            collectors_hierarchy_ids_models.append(collectors_hierarchy_ids_models_item)

        statistics_collector_search_filters = cls(
            connection_name=connection_name,
            schema_table_name=schema_table_name,
            enabled=enabled,
            tags=tags,
            labels=labels,
            column_name=column_name,
            collector_name=collector_name,
            sensor_name=sensor_name,
            collector_category=collector_category,
            target=target,
            collectors_hierarchy_ids_models=collectors_hierarchy_ids_models,
        )

        statistics_collector_search_filters.additional_properties = d
        return statistics_collector_search_filters

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.table_data_freshness_check_spec import TableDataFreshnessCheckSpec
    from ..models.table_data_ingestion_delay_check_spec import (
        TableDataIngestionDelayCheckSpec,
    )
    from ..models.table_data_staleness_check_spec import TableDataStalenessCheckSpec


T = TypeVar("T", bound="TableTimelinessProfilingChecksSpec")


@attr.s(auto_attribs=True)
class TableTimelinessProfilingChecksSpec:
    """
    Attributes:
        profile_data_freshness (Union[Unset, TableDataFreshnessCheckSpec]):
        profile_data_staleness (Union[Unset, TableDataStalenessCheckSpec]):
        profile_data_ingestion_delay (Union[Unset, TableDataIngestionDelayCheckSpec]):
    """

    profile_data_freshness: Union[Unset, "TableDataFreshnessCheckSpec"] = UNSET
    profile_data_staleness: Union[Unset, "TableDataStalenessCheckSpec"] = UNSET
    profile_data_ingestion_delay: Union[
        Unset, "TableDataIngestionDelayCheckSpec"
    ] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        profile_data_freshness: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_data_freshness, Unset):
            profile_data_freshness = self.profile_data_freshness.to_dict()

        profile_data_staleness: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_data_staleness, Unset):
            profile_data_staleness = self.profile_data_staleness.to_dict()

        profile_data_ingestion_delay: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_data_ingestion_delay, Unset):
            profile_data_ingestion_delay = self.profile_data_ingestion_delay.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if profile_data_freshness is not UNSET:
            field_dict["profile_data_freshness"] = profile_data_freshness
        if profile_data_staleness is not UNSET:
            field_dict["profile_data_staleness"] = profile_data_staleness
        if profile_data_ingestion_delay is not UNSET:
            field_dict["profile_data_ingestion_delay"] = profile_data_ingestion_delay

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.table_data_freshness_check_spec import TableDataFreshnessCheckSpec
        from ..models.table_data_ingestion_delay_check_spec import (
            TableDataIngestionDelayCheckSpec,
        )
        from ..models.table_data_staleness_check_spec import TableDataStalenessCheckSpec

        d = src_dict.copy()
        _profile_data_freshness = d.pop("profile_data_freshness", UNSET)
        profile_data_freshness: Union[Unset, TableDataFreshnessCheckSpec]
        if isinstance(_profile_data_freshness, Unset):
            profile_data_freshness = UNSET
        else:
            profile_data_freshness = TableDataFreshnessCheckSpec.from_dict(
                _profile_data_freshness
            )

        _profile_data_staleness = d.pop("profile_data_staleness", UNSET)
        profile_data_staleness: Union[Unset, TableDataStalenessCheckSpec]
        if isinstance(_profile_data_staleness, Unset):
            profile_data_staleness = UNSET
        else:
            profile_data_staleness = TableDataStalenessCheckSpec.from_dict(
                _profile_data_staleness
            )

        _profile_data_ingestion_delay = d.pop("profile_data_ingestion_delay", UNSET)
        profile_data_ingestion_delay: Union[Unset, TableDataIngestionDelayCheckSpec]
        if isinstance(_profile_data_ingestion_delay, Unset):
            profile_data_ingestion_delay = UNSET
        else:
            profile_data_ingestion_delay = TableDataIngestionDelayCheckSpec.from_dict(
                _profile_data_ingestion_delay
            )

        table_timeliness_profiling_checks_spec = cls(
            profile_data_freshness=profile_data_freshness,
            profile_data_staleness=profile_data_staleness,
            profile_data_ingestion_delay=profile_data_ingestion_delay,
        )

        table_timeliness_profiling_checks_spec.additional_properties = d
        return table_timeliness_profiling_checks_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.connection_basic_model_provider_type import (
    ConnectionBasicModelProviderType,
)
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.big_query_parameters_spec import BigQueryParametersSpec
    from ..models.check_search_filters import CheckSearchFilters
    from ..models.delete_stored_data_queue_job_parameters import (
        DeleteStoredDataQueueJobParameters,
    )
    from ..models.mysql_parameters_spec import MysqlParametersSpec
    from ..models.oracle_parameters_spec import OracleParametersSpec
    from ..models.postgresql_parameters_spec import PostgresqlParametersSpec
    from ..models.redshift_parameters_spec import RedshiftParametersSpec
    from ..models.snowflake_parameters_spec import SnowflakeParametersSpec
    from ..models.sql_server_parameters_spec import SqlServerParametersSpec
    from ..models.statistics_collector_search_filters import (
        StatisticsCollectorSearchFilters,
    )


T = TypeVar("T", bound="ConnectionBasicModel")


@attr.s(auto_attribs=True)
class ConnectionBasicModel:
    """Basic connection model with a subset of parameters, excluding all nested objects.

    Attributes:
        connection_name (Union[Unset, str]): Connection name.
        connection_hash (Union[Unset, int]): Connection hash that identifies the connection using a unique hash code.
        parallel_runs_limit (Union[Unset, int]): The concurrency limit for the maximum number of parallel SQL queries
            executed on this connection.
        provider_type (Union[Unset, ConnectionBasicModelProviderType]): Database provider type (required). Accepts:
            bigquery, snowflake.
        bigquery (Union[Unset, BigQueryParametersSpec]):
        snowflake (Union[Unset, SnowflakeParametersSpec]):
        postgresql (Union[Unset, PostgresqlParametersSpec]):
        redshift (Union[Unset, RedshiftParametersSpec]):
        sqlserver (Union[Unset, SqlServerParametersSpec]):
        mysql (Union[Unset, MysqlParametersSpec]):
        oracle (Union[Unset, OracleParametersSpec]):
        run_checks_job_template (Union[Unset, CheckSearchFilters]): Target data quality checks filter, identifies which
            checks on which tables and columns should be executed.
        run_profiling_checks_job_template (Union[Unset, CheckSearchFilters]): Target data quality checks filter,
            identifies which checks on which tables and columns should be executed.
        run_recurring_checks_job_template (Union[Unset, CheckSearchFilters]): Target data quality checks filter,
            identifies which checks on which tables and columns should be executed.
        run_partition_checks_job_template (Union[Unset, CheckSearchFilters]): Target data quality checks filter,
            identifies which checks on which tables and columns should be executed.
        collect_statistics_job_template (Union[Unset, StatisticsCollectorSearchFilters]):
        data_clean_job_template (Union[Unset, DeleteStoredDataQueueJobParameters]):
    """

    connection_name: Union[Unset, str] = UNSET
    connection_hash: Union[Unset, int] = UNSET
    parallel_runs_limit: Union[Unset, int] = UNSET
    provider_type: Union[Unset, ConnectionBasicModelProviderType] = UNSET
    bigquery: Union[Unset, "BigQueryParametersSpec"] = UNSET
    snowflake: Union[Unset, "SnowflakeParametersSpec"] = UNSET
    postgresql: Union[Unset, "PostgresqlParametersSpec"] = UNSET
    redshift: Union[Unset, "RedshiftParametersSpec"] = UNSET
    sqlserver: Union[Unset, "SqlServerParametersSpec"] = UNSET
    mysql: Union[Unset, "MysqlParametersSpec"] = UNSET
    oracle: Union[Unset, "OracleParametersSpec"] = UNSET
    run_checks_job_template: Union[Unset, "CheckSearchFilters"] = UNSET
    run_profiling_checks_job_template: Union[Unset, "CheckSearchFilters"] = UNSET
    run_recurring_checks_job_template: Union[Unset, "CheckSearchFilters"] = UNSET
    run_partition_checks_job_template: Union[Unset, "CheckSearchFilters"] = UNSET
    collect_statistics_job_template: Union[
        Unset, "StatisticsCollectorSearchFilters"
    ] = UNSET
    data_clean_job_template: Union[Unset, "DeleteStoredDataQueueJobParameters"] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        connection_name = self.connection_name
        connection_hash = self.connection_hash
        parallel_runs_limit = self.parallel_runs_limit
        provider_type: Union[Unset, str] = UNSET
        if not isinstance(self.provider_type, Unset):
            provider_type = self.provider_type.value

        bigquery: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.bigquery, Unset):
            bigquery = self.bigquery.to_dict()

        snowflake: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.snowflake, Unset):
            snowflake = self.snowflake.to_dict()

        postgresql: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.postgresql, Unset):
            postgresql = self.postgresql.to_dict()

        redshift: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.redshift, Unset):
            redshift = self.redshift.to_dict()

        sqlserver: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.sqlserver, Unset):
            sqlserver = self.sqlserver.to_dict()

        mysql: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.mysql, Unset):
            mysql = self.mysql.to_dict()

        oracle: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.oracle, Unset):
            oracle = self.oracle.to_dict()

        run_checks_job_template: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.run_checks_job_template, Unset):
            run_checks_job_template = self.run_checks_job_template.to_dict()

        run_profiling_checks_job_template: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.run_profiling_checks_job_template, Unset):
            run_profiling_checks_job_template = (
                self.run_profiling_checks_job_template.to_dict()
            )

        run_recurring_checks_job_template: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.run_recurring_checks_job_template, Unset):
            run_recurring_checks_job_template = (
                self.run_recurring_checks_job_template.to_dict()
            )

        run_partition_checks_job_template: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.run_partition_checks_job_template, Unset):
            run_partition_checks_job_template = (
                self.run_partition_checks_job_template.to_dict()
            )

        collect_statistics_job_template: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.collect_statistics_job_template, Unset):
            collect_statistics_job_template = (
                self.collect_statistics_job_template.to_dict()
            )

        data_clean_job_template: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.data_clean_job_template, Unset):
            data_clean_job_template = self.data_clean_job_template.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if connection_name is not UNSET:
            field_dict["connection_name"] = connection_name
        if connection_hash is not UNSET:
            field_dict["connection_hash"] = connection_hash
        if parallel_runs_limit is not UNSET:
            field_dict["parallel_runs_limit"] = parallel_runs_limit
        if provider_type is not UNSET:
            field_dict["provider_type"] = provider_type
        if bigquery is not UNSET:
            field_dict["bigquery"] = bigquery
        if snowflake is not UNSET:
            field_dict["snowflake"] = snowflake
        if postgresql is not UNSET:
            field_dict["postgresql"] = postgresql
        if redshift is not UNSET:
            field_dict["redshift"] = redshift
        if sqlserver is not UNSET:
            field_dict["sqlserver"] = sqlserver
        if mysql is not UNSET:
            field_dict["mysql"] = mysql
        if oracle is not UNSET:
            field_dict["oracle"] = oracle
        if run_checks_job_template is not UNSET:
            field_dict["run_checks_job_template"] = run_checks_job_template
        if run_profiling_checks_job_template is not UNSET:
            field_dict[
                "run_profiling_checks_job_template"
            ] = run_profiling_checks_job_template
        if run_recurring_checks_job_template is not UNSET:
            field_dict[
                "run_recurring_checks_job_template"
            ] = run_recurring_checks_job_template
        if run_partition_checks_job_template is not UNSET:
            field_dict[
                "run_partition_checks_job_template"
            ] = run_partition_checks_job_template
        if collect_statistics_job_template is not UNSET:
            field_dict[
                "collect_statistics_job_template"
            ] = collect_statistics_job_template
        if data_clean_job_template is not UNSET:
            field_dict["data_clean_job_template"] = data_clean_job_template

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.big_query_parameters_spec import BigQueryParametersSpec
        from ..models.check_search_filters import CheckSearchFilters
        from ..models.delete_stored_data_queue_job_parameters import (
            DeleteStoredDataQueueJobParameters,
        )
        from ..models.mysql_parameters_spec import MysqlParametersSpec
        from ..models.oracle_parameters_spec import OracleParametersSpec
        from ..models.postgresql_parameters_spec import PostgresqlParametersSpec
        from ..models.redshift_parameters_spec import RedshiftParametersSpec
        from ..models.snowflake_parameters_spec import SnowflakeParametersSpec
        from ..models.sql_server_parameters_spec import SqlServerParametersSpec
        from ..models.statistics_collector_search_filters import (
            StatisticsCollectorSearchFilters,
        )

        d = src_dict.copy()
        connection_name = d.pop("connection_name", UNSET)

        connection_hash = d.pop("connection_hash", UNSET)

        parallel_runs_limit = d.pop("parallel_runs_limit", UNSET)

        _provider_type = d.pop("provider_type", UNSET)
        provider_type: Union[Unset, ConnectionBasicModelProviderType]
        if isinstance(_provider_type, Unset):
            provider_type = UNSET
        else:
            provider_type = ConnectionBasicModelProviderType(_provider_type)

        _bigquery = d.pop("bigquery", UNSET)
        bigquery: Union[Unset, BigQueryParametersSpec]
        if isinstance(_bigquery, Unset):
            bigquery = UNSET
        else:
            bigquery = BigQueryParametersSpec.from_dict(_bigquery)

        _snowflake = d.pop("snowflake", UNSET)
        snowflake: Union[Unset, SnowflakeParametersSpec]
        if isinstance(_snowflake, Unset):
            snowflake = UNSET
        else:
            snowflake = SnowflakeParametersSpec.from_dict(_snowflake)

        _postgresql = d.pop("postgresql", UNSET)
        postgresql: Union[Unset, PostgresqlParametersSpec]
        if isinstance(_postgresql, Unset):
            postgresql = UNSET
        else:
            postgresql = PostgresqlParametersSpec.from_dict(_postgresql)

        _redshift = d.pop("redshift", UNSET)
        redshift: Union[Unset, RedshiftParametersSpec]
        if isinstance(_redshift, Unset):
            redshift = UNSET
        else:
            redshift = RedshiftParametersSpec.from_dict(_redshift)

        _sqlserver = d.pop("sqlserver", UNSET)
        sqlserver: Union[Unset, SqlServerParametersSpec]
        if isinstance(_sqlserver, Unset):
            sqlserver = UNSET
        else:
            sqlserver = SqlServerParametersSpec.from_dict(_sqlserver)

        _mysql = d.pop("mysql", UNSET)
        mysql: Union[Unset, MysqlParametersSpec]
        if isinstance(_mysql, Unset):
            mysql = UNSET
        else:
            mysql = MysqlParametersSpec.from_dict(_mysql)

        _oracle = d.pop("oracle", UNSET)
        oracle: Union[Unset, OracleParametersSpec]
        if isinstance(_oracle, Unset):
            oracle = UNSET
        else:
            oracle = OracleParametersSpec.from_dict(_oracle)

        _run_checks_job_template = d.pop("run_checks_job_template", UNSET)
        run_checks_job_template: Union[Unset, CheckSearchFilters]
        if isinstance(_run_checks_job_template, Unset):
            run_checks_job_template = UNSET
        else:
            run_checks_job_template = CheckSearchFilters.from_dict(
                _run_checks_job_template
            )

        _run_profiling_checks_job_template = d.pop(
            "run_profiling_checks_job_template", UNSET
        )
        run_profiling_checks_job_template: Union[Unset, CheckSearchFilters]
        if isinstance(_run_profiling_checks_job_template, Unset):
            run_profiling_checks_job_template = UNSET
        else:
            run_profiling_checks_job_template = CheckSearchFilters.from_dict(
                _run_profiling_checks_job_template
            )

        _run_recurring_checks_job_template = d.pop(
            "run_recurring_checks_job_template", UNSET
        )
        run_recurring_checks_job_template: Union[Unset, CheckSearchFilters]
        if isinstance(_run_recurring_checks_job_template, Unset):
            run_recurring_checks_job_template = UNSET
        else:
            run_recurring_checks_job_template = CheckSearchFilters.from_dict(
                _run_recurring_checks_job_template
            )

        _run_partition_checks_job_template = d.pop(
            "run_partition_checks_job_template", UNSET
        )
        run_partition_checks_job_template: Union[Unset, CheckSearchFilters]
        if isinstance(_run_partition_checks_job_template, Unset):
            run_partition_checks_job_template = UNSET
        else:
            run_partition_checks_job_template = CheckSearchFilters.from_dict(
                _run_partition_checks_job_template
            )

        _collect_statistics_job_template = d.pop(
            "collect_statistics_job_template", UNSET
        )
        collect_statistics_job_template: Union[Unset, StatisticsCollectorSearchFilters]
        if isinstance(_collect_statistics_job_template, Unset):
            collect_statistics_job_template = UNSET
        else:
            collect_statistics_job_template = (
                StatisticsCollectorSearchFilters.from_dict(
                    _collect_statistics_job_template
                )
            )

        _data_clean_job_template = d.pop("data_clean_job_template", UNSET)
        data_clean_job_template: Union[Unset, DeleteStoredDataQueueJobParameters]
        if isinstance(_data_clean_job_template, Unset):
            data_clean_job_template = UNSET
        else:
            data_clean_job_template = DeleteStoredDataQueueJobParameters.from_dict(
                _data_clean_job_template
            )

        connection_basic_model = cls(
            connection_name=connection_name,
            connection_hash=connection_hash,
            parallel_runs_limit=parallel_runs_limit,
            provider_type=provider_type,
            bigquery=bigquery,
            snowflake=snowflake,
            postgresql=postgresql,
            redshift=redshift,
            sqlserver=sqlserver,
            mysql=mysql,
            oracle=oracle,
            run_checks_job_template=run_checks_job_template,
            run_profiling_checks_job_template=run_profiling_checks_job_template,
            run_recurring_checks_job_template=run_recurring_checks_job_template,
            run_partition_checks_job_template=run_partition_checks_job_template,
            collect_statistics_job_template=collect_statistics_job_template,
            data_clean_job_template=data_clean_job_template,
        )

        connection_basic_model.additional_properties = d
        return connection_basic_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class SynchronizeRootFolderParametersDirection(str, Enum):
    DOWNLOAD = "download"
    FULL = "full"
    UPLOAD = "upload"

    def __str__(self) -> str:
        return str(self.value)



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.column_false_percent_check_spec import ColumnFalsePercentCheckSpec
    from ..models.column_true_percent_check_spec import ColumnTruePercentCheckSpec


T = TypeVar("T", bound="ColumnBoolProfilingChecksSpec")


@attr.s(auto_attribs=True)
class ColumnBoolProfilingChecksSpec:
    """
    Attributes:
        profile_true_percent (Union[Unset, ColumnTruePercentCheckSpec]):
        profile_false_percent (Union[Unset, ColumnFalsePercentCheckSpec]):
    """

    profile_true_percent: Union[Unset, "ColumnTruePercentCheckSpec"] = UNSET
    profile_false_percent: Union[Unset, "ColumnFalsePercentCheckSpec"] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        profile_true_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_true_percent, Unset):
            profile_true_percent = self.profile_true_percent.to_dict()

        profile_false_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_false_percent, Unset):
            profile_false_percent = self.profile_false_percent.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if profile_true_percent is not UNSET:
            field_dict["profile_true_percent"] = profile_true_percent
        if profile_false_percent is not UNSET:
            field_dict["profile_false_percent"] = profile_false_percent

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.column_false_percent_check_spec import ColumnFalsePercentCheckSpec
        from ..models.column_true_percent_check_spec import ColumnTruePercentCheckSpec

        d = src_dict.copy()
        _profile_true_percent = d.pop("profile_true_percent", UNSET)
        profile_true_percent: Union[Unset, ColumnTruePercentCheckSpec]
        if isinstance(_profile_true_percent, Unset):
            profile_true_percent = UNSET
        else:
            profile_true_percent = ColumnTruePercentCheckSpec.from_dict(
                _profile_true_percent
            )

        _profile_false_percent = d.pop("profile_false_percent", UNSET)
        profile_false_percent: Union[Unset, ColumnFalsePercentCheckSpec]
        if isinstance(_profile_false_percent, Unset):
            profile_false_percent = UNSET
        else:
            profile_false_percent = ColumnFalsePercentCheckSpec.from_dict(
                _profile_false_percent
            )

        column_bool_profiling_checks_spec = cls(
            profile_true_percent=profile_true_percent,
            profile_false_percent=profile_false_percent,
        )

        column_bool_profiling_checks_spec.additional_properties = d
        return column_bool_profiling_checks_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar

import attr

from ..models.table_data_quality_status_model_failed_checks_statuses_additional_property import (
    TableDataQualityStatusModelFailedChecksStatusesAdditionalProperty,
)

T = TypeVar("T", bound="TableDataQualityStatusModelFailedChecksStatuses")


@attr.s(auto_attribs=True)
class TableDataQualityStatusModelFailedChecksStatuses:
    """The paths to all failed data quality checks (keys) and severity of the highest data quality issue that was detected.
    Table level checks are identified by the check name. Column level checks are identified as a
    check_name[column_name].

    """

    additional_properties: Dict[
        str, TableDataQualityStatusModelFailedChecksStatusesAdditionalProperty
    ] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        field_dict: Dict[str, Any] = {}
        for prop_name, prop in self.additional_properties.items():
            field_dict[prop_name] = prop.value

        field_dict.update({})

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        table_data_quality_status_model_failed_checks_statuses = cls()

        additional_properties = {}
        for prop_name, prop_dict in d.items():
            additional_property = (
                TableDataQualityStatusModelFailedChecksStatusesAdditionalProperty(
                    prop_dict
                )
            )

            additional_properties[prop_name] = additional_property

        table_data_quality_status_model_failed_checks_statuses.additional_properties = (
            additional_properties
        )
        return table_data_quality_status_model_failed_checks_statuses

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(
        self, key: str
    ) -> TableDataQualityStatusModelFailedChecksStatusesAdditionalProperty:
        return self.additional_properties[key]

    def __setitem__(
        self,
        key: str,
        value: TableDataQualityStatusModelFailedChecksStatusesAdditionalProperty,
    ) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.check_spec_basic_model import CheckSpecBasicModel
    from ..models.check_spec_folder_basic_model_folders import (
        CheckSpecFolderBasicModelFolders,
    )


T = TypeVar("T", bound="CheckSpecFolderBasicModel")


@attr.s(auto_attribs=True)
class CheckSpecFolderBasicModel:
    """Check spec folder basic model

    Attributes:
        folders (Union[Unset, CheckSpecFolderBasicModelFolders]): A map of folder-level children checks.
        checks (Union[Unset, List['CheckSpecBasicModel']]): Check basic model list of checks defined at this level.
        all_checks (Union[Unset, List['CheckSpecBasicModel']]):
    """

    folders: Union[Unset, "CheckSpecFolderBasicModelFolders"] = UNSET
    checks: Union[Unset, List["CheckSpecBasicModel"]] = UNSET
    all_checks: Union[Unset, List["CheckSpecBasicModel"]] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        folders: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.folders, Unset):
            folders = self.folders.to_dict()

        checks: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.checks, Unset):
            checks = []
            for checks_item_data in self.checks:
                checks_item = checks_item_data.to_dict()

                checks.append(checks_item)

        all_checks: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.all_checks, Unset):
            all_checks = []
            for all_checks_item_data in self.all_checks:
                all_checks_item = all_checks_item_data.to_dict()

                all_checks.append(all_checks_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if folders is not UNSET:
            field_dict["folders"] = folders
        if checks is not UNSET:
            field_dict["checks"] = checks
        if all_checks is not UNSET:
            field_dict["all_checks"] = all_checks

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.check_spec_basic_model import CheckSpecBasicModel
        from ..models.check_spec_folder_basic_model_folders import (
            CheckSpecFolderBasicModelFolders,
        )

        d = src_dict.copy()
        _folders = d.pop("folders", UNSET)
        folders: Union[Unset, CheckSpecFolderBasicModelFolders]
        if isinstance(_folders, Unset):
            folders = UNSET
        else:
            folders = CheckSpecFolderBasicModelFolders.from_dict(_folders)

        checks = []
        _checks = d.pop("checks", UNSET)
        for checks_item_data in _checks or []:
            checks_item = CheckSpecBasicModel.from_dict(checks_item_data)

            checks.append(checks_item)

        all_checks = []
        _all_checks = d.pop("all_checks", UNSET)
        for all_checks_item_data in _all_checks or []:
            all_checks_item = CheckSpecBasicModel.from_dict(all_checks_item_data)

            all_checks.append(all_checks_item)

        check_spec_folder_basic_model = cls(
            folders=folders,
            checks=checks,
            all_checks=all_checks,
        )

        check_spec_folder_basic_model.additional_properties = d
        return check_spec_folder_basic_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.table_data_freshness_check_spec import TableDataFreshnessCheckSpec
    from ..models.table_data_ingestion_delay_check_spec import (
        TableDataIngestionDelayCheckSpec,
    )
    from ..models.table_data_staleness_check_spec import TableDataStalenessCheckSpec
    from ..models.table_partition_reload_lag_check_spec import (
        TablePartitionReloadLagCheckSpec,
    )


T = TypeVar("T", bound="TableTimelinessMonthlyPartitionedChecksSpec")


@attr.s(auto_attribs=True)
class TableTimelinessMonthlyPartitionedChecksSpec:
    """
    Attributes:
        monthly_partition_data_freshness (Union[Unset, TableDataFreshnessCheckSpec]):
        monthly_partition_data_staleness (Union[Unset, TableDataStalenessCheckSpec]):
        monthly_partition_data_ingestion_delay (Union[Unset, TableDataIngestionDelayCheckSpec]):
        monthly_partition_reload_lag (Union[Unset, TablePartitionReloadLagCheckSpec]):
    """

    monthly_partition_data_freshness: Union[
        Unset, "TableDataFreshnessCheckSpec"
    ] = UNSET
    monthly_partition_data_staleness: Union[
        Unset, "TableDataStalenessCheckSpec"
    ] = UNSET
    monthly_partition_data_ingestion_delay: Union[
        Unset, "TableDataIngestionDelayCheckSpec"
    ] = UNSET
    monthly_partition_reload_lag: Union[
        Unset, "TablePartitionReloadLagCheckSpec"
    ] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        monthly_partition_data_freshness: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_partition_data_freshness, Unset):
            monthly_partition_data_freshness = (
                self.monthly_partition_data_freshness.to_dict()
            )

        monthly_partition_data_staleness: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_partition_data_staleness, Unset):
            monthly_partition_data_staleness = (
                self.monthly_partition_data_staleness.to_dict()
            )

        monthly_partition_data_ingestion_delay: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_partition_data_ingestion_delay, Unset):
            monthly_partition_data_ingestion_delay = (
                self.monthly_partition_data_ingestion_delay.to_dict()
            )

        monthly_partition_reload_lag: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_partition_reload_lag, Unset):
            monthly_partition_reload_lag = self.monthly_partition_reload_lag.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if monthly_partition_data_freshness is not UNSET:
            field_dict[
                "monthly_partition_data_freshness"
            ] = monthly_partition_data_freshness
        if monthly_partition_data_staleness is not UNSET:
            field_dict[
                "monthly_partition_data_staleness"
            ] = monthly_partition_data_staleness
        if monthly_partition_data_ingestion_delay is not UNSET:
            field_dict[
                "monthly_partition_data_ingestion_delay"
            ] = monthly_partition_data_ingestion_delay
        if monthly_partition_reload_lag is not UNSET:
            field_dict["monthly_partition_reload_lag"] = monthly_partition_reload_lag

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.table_data_freshness_check_spec import TableDataFreshnessCheckSpec
        from ..models.table_data_ingestion_delay_check_spec import (
            TableDataIngestionDelayCheckSpec,
        )
        from ..models.table_data_staleness_check_spec import TableDataStalenessCheckSpec
        from ..models.table_partition_reload_lag_check_spec import (
            TablePartitionReloadLagCheckSpec,
        )

        d = src_dict.copy()
        _monthly_partition_data_freshness = d.pop(
            "monthly_partition_data_freshness", UNSET
        )
        monthly_partition_data_freshness: Union[Unset, TableDataFreshnessCheckSpec]
        if isinstance(_monthly_partition_data_freshness, Unset):
            monthly_partition_data_freshness = UNSET
        else:
            monthly_partition_data_freshness = TableDataFreshnessCheckSpec.from_dict(
                _monthly_partition_data_freshness
            )

        _monthly_partition_data_staleness = d.pop(
            "monthly_partition_data_staleness", UNSET
        )
        monthly_partition_data_staleness: Union[Unset, TableDataStalenessCheckSpec]
        if isinstance(_monthly_partition_data_staleness, Unset):
            monthly_partition_data_staleness = UNSET
        else:
            monthly_partition_data_staleness = TableDataStalenessCheckSpec.from_dict(
                _monthly_partition_data_staleness
            )

        _monthly_partition_data_ingestion_delay = d.pop(
            "monthly_partition_data_ingestion_delay", UNSET
        )
        monthly_partition_data_ingestion_delay: Union[
            Unset, TableDataIngestionDelayCheckSpec
        ]
        if isinstance(_monthly_partition_data_ingestion_delay, Unset):
            monthly_partition_data_ingestion_delay = UNSET
        else:
            monthly_partition_data_ingestion_delay = (
                TableDataIngestionDelayCheckSpec.from_dict(
                    _monthly_partition_data_ingestion_delay
                )
            )

        _monthly_partition_reload_lag = d.pop("monthly_partition_reload_lag", UNSET)
        monthly_partition_reload_lag: Union[Unset, TablePartitionReloadLagCheckSpec]
        if isinstance(_monthly_partition_reload_lag, Unset):
            monthly_partition_reload_lag = UNSET
        else:
            monthly_partition_reload_lag = TablePartitionReloadLagCheckSpec.from_dict(
                _monthly_partition_reload_lag
            )

        table_timeliness_monthly_partitioned_checks_spec = cls(
            monthly_partition_data_freshness=monthly_partition_data_freshness,
            monthly_partition_data_staleness=monthly_partition_data_staleness,
            monthly_partition_data_ingestion_delay=monthly_partition_data_ingestion_delay,
            monthly_partition_reload_lag=monthly_partition_reload_lag,
        )

        table_timeliness_monthly_partitioned_checks_spec.additional_properties = d
        return table_timeliness_monthly_partitioned_checks_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.column_comparison_max_match_check_spec import (
        ColumnComparisonMaxMatchCheckSpec,
    )
    from ..models.column_comparison_mean_match_check_spec import (
        ColumnComparisonMeanMatchCheckSpec,
    )
    from ..models.column_comparison_min_match_check_spec import (
        ColumnComparisonMinMatchCheckSpec,
    )
    from ..models.column_comparison_not_null_count_match_check_spec import (
        ColumnComparisonNotNullCountMatchCheckSpec,
    )
    from ..models.column_comparison_null_count_match_check_spec import (
        ColumnComparisonNullCountMatchCheckSpec,
    )
    from ..models.column_comparison_sum_match_check_spec import (
        ColumnComparisonSumMatchCheckSpec,
    )


T = TypeVar("T", bound="ColumnComparisonDailyRecurringChecksSpec")


@attr.s(auto_attribs=True)
class ColumnComparisonDailyRecurringChecksSpec:
    """
    Attributes:
        reference_column (Union[Unset, str]): The name of the reference column name in the reference table. It is the
            column to which the current column is compared to.
        daily_sum_match (Union[Unset, ColumnComparisonSumMatchCheckSpec]):
        daily_min_match (Union[Unset, ColumnComparisonMinMatchCheckSpec]):
        daily_max_match (Union[Unset, ColumnComparisonMaxMatchCheckSpec]):
        daily_mean_match (Union[Unset, ColumnComparisonMeanMatchCheckSpec]):
        daily_not_null_count_match (Union[Unset, ColumnComparisonNotNullCountMatchCheckSpec]):
        daily_null_count_match (Union[Unset, ColumnComparisonNullCountMatchCheckSpec]):
    """

    reference_column: Union[Unset, str] = UNSET
    daily_sum_match: Union[Unset, "ColumnComparisonSumMatchCheckSpec"] = UNSET
    daily_min_match: Union[Unset, "ColumnComparisonMinMatchCheckSpec"] = UNSET
    daily_max_match: Union[Unset, "ColumnComparisonMaxMatchCheckSpec"] = UNSET
    daily_mean_match: Union[Unset, "ColumnComparisonMeanMatchCheckSpec"] = UNSET
    daily_not_null_count_match: Union[
        Unset, "ColumnComparisonNotNullCountMatchCheckSpec"
    ] = UNSET
    daily_null_count_match: Union[
        Unset, "ColumnComparisonNullCountMatchCheckSpec"
    ] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        reference_column = self.reference_column
        daily_sum_match: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.daily_sum_match, Unset):
            daily_sum_match = self.daily_sum_match.to_dict()

        daily_min_match: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.daily_min_match, Unset):
            daily_min_match = self.daily_min_match.to_dict()

        daily_max_match: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.daily_max_match, Unset):
            daily_max_match = self.daily_max_match.to_dict()

        daily_mean_match: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.daily_mean_match, Unset):
            daily_mean_match = self.daily_mean_match.to_dict()

        daily_not_null_count_match: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.daily_not_null_count_match, Unset):
            daily_not_null_count_match = self.daily_not_null_count_match.to_dict()

        daily_null_count_match: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.daily_null_count_match, Unset):
            daily_null_count_match = self.daily_null_count_match.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if reference_column is not UNSET:
            field_dict["reference_column"] = reference_column
        if daily_sum_match is not UNSET:
            field_dict["daily_sum_match"] = daily_sum_match
        if daily_min_match is not UNSET:
            field_dict["daily_min_match"] = daily_min_match
        if daily_max_match is not UNSET:
            field_dict["daily_max_match"] = daily_max_match
        if daily_mean_match is not UNSET:
            field_dict["daily_mean_match"] = daily_mean_match
        if daily_not_null_count_match is not UNSET:
            field_dict["daily_not_null_count_match"] = daily_not_null_count_match
        if daily_null_count_match is not UNSET:
            field_dict["daily_null_count_match"] = daily_null_count_match

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.column_comparison_max_match_check_spec import (
            ColumnComparisonMaxMatchCheckSpec,
        )
        from ..models.column_comparison_mean_match_check_spec import (
            ColumnComparisonMeanMatchCheckSpec,
        )
        from ..models.column_comparison_min_match_check_spec import (
            ColumnComparisonMinMatchCheckSpec,
        )
        from ..models.column_comparison_not_null_count_match_check_spec import (
            ColumnComparisonNotNullCountMatchCheckSpec,
        )
        from ..models.column_comparison_null_count_match_check_spec import (
            ColumnComparisonNullCountMatchCheckSpec,
        )
        from ..models.column_comparison_sum_match_check_spec import (
            ColumnComparisonSumMatchCheckSpec,
        )

        d = src_dict.copy()
        reference_column = d.pop("reference_column", UNSET)

        _daily_sum_match = d.pop("daily_sum_match", UNSET)
        daily_sum_match: Union[Unset, ColumnComparisonSumMatchCheckSpec]
        if isinstance(_daily_sum_match, Unset):
            daily_sum_match = UNSET
        else:
            daily_sum_match = ColumnComparisonSumMatchCheckSpec.from_dict(
                _daily_sum_match
            )

        _daily_min_match = d.pop("daily_min_match", UNSET)
        daily_min_match: Union[Unset, ColumnComparisonMinMatchCheckSpec]
        if isinstance(_daily_min_match, Unset):
            daily_min_match = UNSET
        else:
            daily_min_match = ColumnComparisonMinMatchCheckSpec.from_dict(
                _daily_min_match
            )

        _daily_max_match = d.pop("daily_max_match", UNSET)
        daily_max_match: Union[Unset, ColumnComparisonMaxMatchCheckSpec]
        if isinstance(_daily_max_match, Unset):
            daily_max_match = UNSET
        else:
            daily_max_match = ColumnComparisonMaxMatchCheckSpec.from_dict(
                _daily_max_match
            )

        _daily_mean_match = d.pop("daily_mean_match", UNSET)
        daily_mean_match: Union[Unset, ColumnComparisonMeanMatchCheckSpec]
        if isinstance(_daily_mean_match, Unset):
            daily_mean_match = UNSET
        else:
            daily_mean_match = ColumnComparisonMeanMatchCheckSpec.from_dict(
                _daily_mean_match
            )

        _daily_not_null_count_match = d.pop("daily_not_null_count_match", UNSET)
        daily_not_null_count_match: Union[
            Unset, ColumnComparisonNotNullCountMatchCheckSpec
        ]
        if isinstance(_daily_not_null_count_match, Unset):
            daily_not_null_count_match = UNSET
        else:
            daily_not_null_count_match = (
                ColumnComparisonNotNullCountMatchCheckSpec.from_dict(
                    _daily_not_null_count_match
                )
            )

        _daily_null_count_match = d.pop("daily_null_count_match", UNSET)
        daily_null_count_match: Union[Unset, ColumnComparisonNullCountMatchCheckSpec]
        if isinstance(_daily_null_count_match, Unset):
            daily_null_count_match = UNSET
        else:
            daily_null_count_match = ColumnComparisonNullCountMatchCheckSpec.from_dict(
                _daily_null_count_match
            )

        column_comparison_daily_recurring_checks_spec = cls(
            reference_column=reference_column,
            daily_sum_match=daily_sum_match,
            daily_min_match=daily_min_match,
            daily_max_match=daily_max_match,
            daily_mean_match=daily_mean_match,
            daily_not_null_count_match=daily_not_null_count_match,
            daily_null_count_match=daily_null_count_match,
        )

        column_comparison_daily_recurring_checks_spec.additional_properties = d
        return column_comparison_daily_recurring_checks_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.table_anomaly_differencing_row_count_30_days_check_spec import (
        TableAnomalyDifferencingRowCount30DaysCheckSpec,
    )
    from ..models.table_anomaly_differencing_row_count_check_spec import (
        TableAnomalyDifferencingRowCountCheckSpec,
    )
    from ..models.table_change_row_count_check_spec import TableChangeRowCountCheckSpec
    from ..models.table_change_row_count_since_7_days_check_spec import (
        TableChangeRowCountSince7DaysCheckSpec,
    )
    from ..models.table_change_row_count_since_30_days_check_spec import (
        TableChangeRowCountSince30DaysCheckSpec,
    )
    from ..models.table_change_row_count_since_yesterday_check_spec import (
        TableChangeRowCountSinceYesterdayCheckSpec,
    )
    from ..models.table_row_count_check_spec import TableRowCountCheckSpec


T = TypeVar("T", bound="TableVolumeProfilingChecksSpec")


@attr.s(auto_attribs=True)
class TableVolumeProfilingChecksSpec:
    """
    Attributes:
        profile_row_count (Union[Unset, TableRowCountCheckSpec]):
        profile_row_count_change (Union[Unset, TableChangeRowCountCheckSpec]):
        profile_row_count_change_yesterday (Union[Unset, TableChangeRowCountSinceYesterdayCheckSpec]):
        profile_row_count_anomaly_differencing_30_days (Union[Unset, TableAnomalyDifferencingRowCount30DaysCheckSpec]):
        profile_row_count_anomaly_differencing (Union[Unset, TableAnomalyDifferencingRowCountCheckSpec]):
        profile_row_count_change_7_days (Union[Unset, TableChangeRowCountSince7DaysCheckSpec]):
        profile_row_count_change_30_days (Union[Unset, TableChangeRowCountSince30DaysCheckSpec]):
    """

    profile_row_count: Union[Unset, "TableRowCountCheckSpec"] = UNSET
    profile_row_count_change: Union[Unset, "TableChangeRowCountCheckSpec"] = UNSET
    profile_row_count_change_yesterday: Union[
        Unset, "TableChangeRowCountSinceYesterdayCheckSpec"
    ] = UNSET
    profile_row_count_anomaly_differencing_30_days: Union[
        Unset, "TableAnomalyDifferencingRowCount30DaysCheckSpec"
    ] = UNSET
    profile_row_count_anomaly_differencing: Union[
        Unset, "TableAnomalyDifferencingRowCountCheckSpec"
    ] = UNSET
    profile_row_count_change_7_days: Union[
        Unset, "TableChangeRowCountSince7DaysCheckSpec"
    ] = UNSET
    profile_row_count_change_30_days: Union[
        Unset, "TableChangeRowCountSince30DaysCheckSpec"
    ] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        profile_row_count: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_row_count, Unset):
            profile_row_count = self.profile_row_count.to_dict()

        profile_row_count_change: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_row_count_change, Unset):
            profile_row_count_change = self.profile_row_count_change.to_dict()

        profile_row_count_change_yesterday: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_row_count_change_yesterday, Unset):
            profile_row_count_change_yesterday = (
                self.profile_row_count_change_yesterday.to_dict()
            )

        profile_row_count_anomaly_differencing_30_days: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(self.profile_row_count_anomaly_differencing_30_days, Unset):
            profile_row_count_anomaly_differencing_30_days = (
                self.profile_row_count_anomaly_differencing_30_days.to_dict()
            )

        profile_row_count_anomaly_differencing: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_row_count_anomaly_differencing, Unset):
            profile_row_count_anomaly_differencing = (
                self.profile_row_count_anomaly_differencing.to_dict()
            )

        profile_row_count_change_7_days: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_row_count_change_7_days, Unset):
            profile_row_count_change_7_days = (
                self.profile_row_count_change_7_days.to_dict()
            )

        profile_row_count_change_30_days: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_row_count_change_30_days, Unset):
            profile_row_count_change_30_days = (
                self.profile_row_count_change_30_days.to_dict()
            )

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if profile_row_count is not UNSET:
            field_dict["profile_row_count"] = profile_row_count
        if profile_row_count_change is not UNSET:
            field_dict["profile_row_count_change"] = profile_row_count_change
        if profile_row_count_change_yesterday is not UNSET:
            field_dict[
                "profile_row_count_change_yesterday"
            ] = profile_row_count_change_yesterday
        if profile_row_count_anomaly_differencing_30_days is not UNSET:
            field_dict[
                "profile_row_count_anomaly_differencing_30_days"
            ] = profile_row_count_anomaly_differencing_30_days
        if profile_row_count_anomaly_differencing is not UNSET:
            field_dict[
                "profile_row_count_anomaly_differencing"
            ] = profile_row_count_anomaly_differencing
        if profile_row_count_change_7_days is not UNSET:
            field_dict[
                "profile_row_count_change_7_days"
            ] = profile_row_count_change_7_days
        if profile_row_count_change_30_days is not UNSET:
            field_dict[
                "profile_row_count_change_30_days"
            ] = profile_row_count_change_30_days

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.table_anomaly_differencing_row_count_30_days_check_spec import (
            TableAnomalyDifferencingRowCount30DaysCheckSpec,
        )
        from ..models.table_anomaly_differencing_row_count_check_spec import (
            TableAnomalyDifferencingRowCountCheckSpec,
        )
        from ..models.table_change_row_count_check_spec import (
            TableChangeRowCountCheckSpec,
        )
        from ..models.table_change_row_count_since_7_days_check_spec import (
            TableChangeRowCountSince7DaysCheckSpec,
        )
        from ..models.table_change_row_count_since_30_days_check_spec import (
            TableChangeRowCountSince30DaysCheckSpec,
        )
        from ..models.table_change_row_count_since_yesterday_check_spec import (
            TableChangeRowCountSinceYesterdayCheckSpec,
        )
        from ..models.table_row_count_check_spec import TableRowCountCheckSpec

        d = src_dict.copy()
        _profile_row_count = d.pop("profile_row_count", UNSET)
        profile_row_count: Union[Unset, TableRowCountCheckSpec]
        if isinstance(_profile_row_count, Unset):
            profile_row_count = UNSET
        else:
            profile_row_count = TableRowCountCheckSpec.from_dict(_profile_row_count)

        _profile_row_count_change = d.pop("profile_row_count_change", UNSET)
        profile_row_count_change: Union[Unset, TableChangeRowCountCheckSpec]
        if isinstance(_profile_row_count_change, Unset):
            profile_row_count_change = UNSET
        else:
            profile_row_count_change = TableChangeRowCountCheckSpec.from_dict(
                _profile_row_count_change
            )

        _profile_row_count_change_yesterday = d.pop(
            "profile_row_count_change_yesterday", UNSET
        )
        profile_row_count_change_yesterday: Union[
            Unset, TableChangeRowCountSinceYesterdayCheckSpec
        ]
        if isinstance(_profile_row_count_change_yesterday, Unset):
            profile_row_count_change_yesterday = UNSET
        else:
            profile_row_count_change_yesterday = (
                TableChangeRowCountSinceYesterdayCheckSpec.from_dict(
                    _profile_row_count_change_yesterday
                )
            )

        _profile_row_count_anomaly_differencing_30_days = d.pop(
            "profile_row_count_anomaly_differencing_30_days", UNSET
        )
        profile_row_count_anomaly_differencing_30_days: Union[
            Unset, TableAnomalyDifferencingRowCount30DaysCheckSpec
        ]
        if isinstance(_profile_row_count_anomaly_differencing_30_days, Unset):
            profile_row_count_anomaly_differencing_30_days = UNSET
        else:
            profile_row_count_anomaly_differencing_30_days = (
                TableAnomalyDifferencingRowCount30DaysCheckSpec.from_dict(
                    _profile_row_count_anomaly_differencing_30_days
                )
            )

        _profile_row_count_anomaly_differencing = d.pop(
            "profile_row_count_anomaly_differencing", UNSET
        )
        profile_row_count_anomaly_differencing: Union[
            Unset, TableAnomalyDifferencingRowCountCheckSpec
        ]
        if isinstance(_profile_row_count_anomaly_differencing, Unset):
            profile_row_count_anomaly_differencing = UNSET
        else:
            profile_row_count_anomaly_differencing = (
                TableAnomalyDifferencingRowCountCheckSpec.from_dict(
                    _profile_row_count_anomaly_differencing
                )
            )

        _profile_row_count_change_7_days = d.pop(
            "profile_row_count_change_7_days", UNSET
        )
        profile_row_count_change_7_days: Union[
            Unset, TableChangeRowCountSince7DaysCheckSpec
        ]
        if isinstance(_profile_row_count_change_7_days, Unset):
            profile_row_count_change_7_days = UNSET
        else:
            profile_row_count_change_7_days = (
                TableChangeRowCountSince7DaysCheckSpec.from_dict(
                    _profile_row_count_change_7_days
                )
            )

        _profile_row_count_change_30_days = d.pop(
            "profile_row_count_change_30_days", UNSET
        )
        profile_row_count_change_30_days: Union[
            Unset, TableChangeRowCountSince30DaysCheckSpec
        ]
        if isinstance(_profile_row_count_change_30_days, Unset):
            profile_row_count_change_30_days = UNSET
        else:
            profile_row_count_change_30_days = (
                TableChangeRowCountSince30DaysCheckSpec.from_dict(
                    _profile_row_count_change_30_days
                )
            )

        table_volume_profiling_checks_spec = cls(
            profile_row_count=profile_row_count,
            profile_row_count_change=profile_row_count_change,
            profile_row_count_change_yesterday=profile_row_count_change_yesterday,
            profile_row_count_anomaly_differencing_30_days=profile_row_count_anomaly_differencing_30_days,
            profile_row_count_anomaly_differencing=profile_row_count_anomaly_differencing,
            profile_row_count_change_7_days=profile_row_count_change_7_days,
            profile_row_count_change_30_days=profile_row_count_change_30_days,
        )

        table_volume_profiling_checks_spec.additional_properties = d
        return table_volume_profiling_checks_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class TableProfilingCheckCategoriesSpecResultTruncation(str, Enum):
    ALL_RESULTS = "all_results"
    ONE_PER_DAY = "one_per_day"
    ONE_PER_HOUR = "one_per_hour"
    ONE_PER_MONTH = "one_per_month"
    ONE_PER_WEEK = "one_per_week"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class DqoJobHistoryEntryModelJobType(str, Enum):
    COLLECT_STATISTICS = "collect statistics"
    COLLECT_STATISTICS_ON_TABLE = "collect statistics on table"
    DELETE_STORED_DATA = "delete stored data"
    IMPORT_SCHEMA = "import schema"
    IMPORT_SELECTED_TABLES = "import selected tables"
    QUEUE_THREAD_SHUTDOWN = "queue thread shutdown"
    REPAIR_STORED_DATA = "repair stored data"
    RUN_CHECKS = "run checks"
    RUN_CHECKS_ON_TABLE = "run checks on table"
    RUN_SCHEDULED_CHECKS_BY_CRON = "run scheduled checks by cron"
    SYNCHRONIZE_FOLDER = "synchronize folder"
    SYNCHRONIZE_MULTIPLE_FOLDERS = "synchronize multiple folders"

    def __str__(self) -> str:
        return str(self.value)



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.recurring_schedule_spec import RecurringScheduleSpec


T = TypeVar("T", bound="RecurringSchedulesSpec")


@attr.s(auto_attribs=True)
class RecurringSchedulesSpec:
    """
    Attributes:
        profiling (Union[Unset, RecurringScheduleSpec]):
        recurring_daily (Union[Unset, RecurringScheduleSpec]):
        recurring_monthly (Union[Unset, RecurringScheduleSpec]):
        partitioned_daily (Union[Unset, RecurringScheduleSpec]):
        partitioned_monthly (Union[Unset, RecurringScheduleSpec]):
    """

    profiling: Union[Unset, "RecurringScheduleSpec"] = UNSET
    recurring_daily: Union[Unset, "RecurringScheduleSpec"] = UNSET
    recurring_monthly: Union[Unset, "RecurringScheduleSpec"] = UNSET
    partitioned_daily: Union[Unset, "RecurringScheduleSpec"] = UNSET
    partitioned_monthly: Union[Unset, "RecurringScheduleSpec"] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        profiling: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profiling, Unset):
            profiling = self.profiling.to_dict()

        recurring_daily: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.recurring_daily, Unset):
            recurring_daily = self.recurring_daily.to_dict()

        recurring_monthly: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.recurring_monthly, Unset):
            recurring_monthly = self.recurring_monthly.to_dict()

        partitioned_daily: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.partitioned_daily, Unset):
            partitioned_daily = self.partitioned_daily.to_dict()

        partitioned_monthly: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.partitioned_monthly, Unset):
            partitioned_monthly = self.partitioned_monthly.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if profiling is not UNSET:
            field_dict["profiling"] = profiling
        if recurring_daily is not UNSET:
            field_dict["recurring_daily"] = recurring_daily
        if recurring_monthly is not UNSET:
            field_dict["recurring_monthly"] = recurring_monthly
        if partitioned_daily is not UNSET:
            field_dict["partitioned_daily"] = partitioned_daily
        if partitioned_monthly is not UNSET:
            field_dict["partitioned_monthly"] = partitioned_monthly

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.recurring_schedule_spec import RecurringScheduleSpec

        d = src_dict.copy()
        _profiling = d.pop("profiling", UNSET)
        profiling: Union[Unset, RecurringScheduleSpec]
        if isinstance(_profiling, Unset):
            profiling = UNSET
        else:
            profiling = RecurringScheduleSpec.from_dict(_profiling)

        _recurring_daily = d.pop("recurring_daily", UNSET)
        recurring_daily: Union[Unset, RecurringScheduleSpec]
        if isinstance(_recurring_daily, Unset):
            recurring_daily = UNSET
        else:
            recurring_daily = RecurringScheduleSpec.from_dict(_recurring_daily)

        _recurring_monthly = d.pop("recurring_monthly", UNSET)
        recurring_monthly: Union[Unset, RecurringScheduleSpec]
        if isinstance(_recurring_monthly, Unset):
            recurring_monthly = UNSET
        else:
            recurring_monthly = RecurringScheduleSpec.from_dict(_recurring_monthly)

        _partitioned_daily = d.pop("partitioned_daily", UNSET)
        partitioned_daily: Union[Unset, RecurringScheduleSpec]
        if isinstance(_partitioned_daily, Unset):
            partitioned_daily = UNSET
        else:
            partitioned_daily = RecurringScheduleSpec.from_dict(_partitioned_daily)

        _partitioned_monthly = d.pop("partitioned_monthly", UNSET)
        partitioned_monthly: Union[Unset, RecurringScheduleSpec]
        if isinstance(_partitioned_monthly, Unset):
            partitioned_monthly = UNSET
        else:
            partitioned_monthly = RecurringScheduleSpec.from_dict(_partitioned_monthly)

        recurring_schedules_spec = cls(
            profiling=profiling,
            recurring_daily=recurring_daily,
            recurring_monthly=recurring_monthly,
            partitioned_daily=partitioned_daily,
            partitioned_monthly=partitioned_monthly,
        )

        recurring_schedules_spec.additional_properties = d
        return recurring_schedules_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
